package com.xkrs.microservice.common.tool;

import com.xkrs.microservice.model.vo.ForecastWeather7DayVo;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.time.LocalDate;
import java.util.HashMap;
import java.util.Map;

import static com.xkrs.microservice.util.DateTimeUtil.dateToStringNoLine;

/**
 * 爬取静态页面 新版中国天气网7天
 * @author wd
 */

public class CrawlingWeather7Day {

    private static final Logger log = LoggerFactory.getLogger(CrawlingWeather7Day.class);

    /**
     * 获取7天的天气预报和昨天的历史数据
     * {d0:昨天 。。。。。 d7:第七天}
     * @param cityCode 城市编码
     * @param stationId 气象站点id
     */
    public static ForecastWeather7DayVo getReptileWeather7Day(String cityCode, String stationId) {
        // 城市
        String city = null;
        // 天气
        String[] weather = new String[8];
        // 风向
        String[] wd = new String[8];
        // 风力
        String[] ws = new String[8];
        // 最高温数组
        String[] tempMax = new String[8];
        // 最低温数组
        String[] tempMin = new String[8];
        // 天气数组
        Map<String, String> weatherMap = new HashMap<>(8);
        // 昨天天气
        Map<String, String> weatherYesterMap = new HashMap<>(8);
        // 7天预报和昨天数据
        Map<String, Map<String, String>> weatherMap7Day = new HashMap<>(8);

        // 爬取成功标志
        boolean isSuccess = false;

        // 重复次数
        int retryTimes = 5;

        // 时间
        LocalDate localDate = LocalDate.now();

        // 降水数据
        Map<String, String> rainForecast =getRainForecast(stationId);

        String url = "http://www.weather.com.cn/weathern/" + cityCode + ".shtml";
        while (!isSuccess && retryTimes > 0) {
            try {
                // 获得连接
                Document doc = Jsoup.connect(url).timeout(10000).get();
                // 获得地址
                Elements localEle = doc.getElementsByClass("webox");

                StringBuffer sb = new StringBuffer();
                for (Element e : localEle) {
                    sb.append(e.getElementsByTag("a").text().substring(0, 2));
                    sb.append(">");
                }
                String citySb = sb.toString();
                if (citySb.trim().isEmpty()) {
                    log.info("city 为空");
                } else {
                    city = citySb.substring(0, citySb.length() - 1);
                    weatherYesterMap.put("city", city);
                }


                Elements conEle = doc.getElementsByClass("blueFor-container");
                for (Element e : conEle) {

                    // 获得气温数组
                    Document eDoc = Jsoup.parse(e.toString());
                    // script有两个，一个是7天、15天的气温，一个是小时预报
                    Elements scripts = eDoc.getElementsByTag("script");
                    //拿到气温数据
                    Elements eq = scripts.eq(0);

                    for (Element ele :
                            eq) {
                        String[] datas = ele.data().split("var");
                        for (String data :
                                datas) {
                            // 数据不为空，包含"="
                            if (data.contains("=")) {
                                String[] datass = data.split("=");
                                if ("eventDay".equals(datass[0].trim())) {
                                    String dataSquare = data.split("=")[1];

                                    tempMax = getTemp(dataSquare);
                                }
                                if ("eventNight".equals(datass[0].trim())) {
                                    String dataSquare = data.split("=")[1];
                                    tempMin = getTemp(dataSquare);
                                }
                            }
                        }
                        weatherYesterMap.put("tempMax", tempMax[0]);
                        weatherYesterMap.put("tempMin", tempMin[0]);

                        // 昨天天气
                        Elements yestEle = eDoc.select("li[class^=blue-item yesterday]");
                        // 获得天气
                        weather[0] = yestEle.select("p[class^=weather-info info-style]").text();
                        weatherYesterMap.put("weather", weather[0]);

                        // 获得风气
                        Elements winds = yestEle.select("i[class^=wind-icon]");

                        StringBuffer sbb = new StringBuffer();
                        for (Element wind :
                                winds) {
                            sbb.append(wind.getElementsByTag("i").attr("title"));
                            sbb.append(">");
                        }
                        String sbbs = sbb.toString();
                        wd[0] = sbbs.substring(0, sbbs.length() - 1);
                        weatherYesterMap.put("wd", wd[0]);
                        // 风力
                        ws[0] = yestEle.select("p[class^=wind-info  info-style]").text();

                        weatherYesterMap.put("ws", ws[0]);
                        weatherYesterMap.put("rain", null);

                        weatherMap7Day.put("d0", weatherYesterMap);


                        // 7天天气预报
                        Elements forecasts = eDoc.select("li[class^=blue-item lv]");

                        int i = 1;
                        for (Element e1 :
                                forecasts) {
                            // 时间
                            LocalDate date = localDate.plusDays(i - 1);
                            // 天气数组
                            weatherMap = new HashMap<>(7);

                            String day = "d" + i;
                            // 天气
                            weather[i] = e1.select("p[class^=weather-info]").get(0).text();
                            weatherMap.put("weather", weather[i]);
                            // 获得风气
                            Elements winds7Day = e1.select("i[class^=wind-icon]");

                            sbb.setLength(0);
                            sbb.delete(0, sbb.length());
                            for (Element wind :
                                    winds7Day) {
                                sbb.append(wind.getElementsByTag("i").attr("title"));
                                sbb.append(">");
                            }
                            sbbs = sbb.toString();
                            wd[i] = sbbs.substring(0, sbbs.length() - 1);
                            weatherMap.put("wd", wd[i]);
                            // 风力
                            ws[i] = e1.select("p[class^=wind-info]").text();
                            weatherMap.put("ws", ws[i]);
                            weatherMap.put("tempMax", tempMax[i]);
                            weatherMap.put("tempMin", tempMin[i]);
                            weatherMap.put("city",city);

                            // 三天内的数据又降水预报，站点数据
                            if (i < 4){
                                weatherMap.put("rain",rainForecast.get(dateToStringNoLine(date)));
                            }else{
                                weatherMap.put("rain","null");
                            }
                            weatherMap7Day.put(day, weatherMap);
                            i++;
                        }
                    }
                }
                isSuccess = true;
            } catch (IOException e) {
                log.info("连接超时");
                retryTimes--;
                try {
                    Thread.sleep(2000);
                } catch (InterruptedException ex) {
                    ex.printStackTrace();
                }
            }
        }
        log.info("天气查询完毕");
        ForecastWeather7DayVo forecastWeather7DayVo = new ForecastWeather7DayVo();
        forecastWeather7DayVo.setCity(city);
        forecastWeather7DayVo.setTempMax(tempMax);
        forecastWeather7DayVo.setTempMin(tempMin);
        forecastWeather7DayVo.setWd(wd);
        forecastWeather7DayVo.setWs(ws);
        forecastWeather7DayVo.setWeather(weather);
        forecastWeather7DayVo.setWeatherMap7Day(weatherMap7Day);
        return forecastWeather7DayVo;
    }

    /**
     * 气温数据存储
     * @param data 气温字符串
     */
    private static String[] getTemp(String data) {
        String[] temps = data.substring(1, data.length() - 3).split(",");
        String[] temp = new String[8];
        for (int i = 0; i < temps.length; i++) {
            temp[i] = temps[i].substring(1, temps[i].length() - 1);
        }
        return temp;
    }

    /**
     * 获取降水量预报
     * @param cityStationId 城市站点id
     */
    public static Map<String, String> getRainForecast(String cityStationId) {
        Map<String,String> map = new HashMap<>(3);

        map.put("staId",cityStationId);
        map.put("funitemmenuid","1150101020");
        map.put("typeCode","NWST");
        map.put("url", Precipitation.FORECAST_PERCIPITION_URL);
        return Precipitation.forecastDataHandler(map);
    }

    public static void main(String[] args) {
        ForecastWeather7DayVo res = getReptileWeather7Day("101121304","54861");
        System.out.println(res);
    }
}
