package com.xkrs.microservice.common.tool;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.xkrs.microservice.model.vo.RealTimeWeatherVo;
import org.apache.http.HttpEntity;
import org.apache.http.HttpStatus;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.utils.URIBuilder;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.time.LocalDateTime;

import static com.xkrs.microservice.util.DateTimeUtil.dateTimeToString;


/**
 * 得到实时数据
 * @author wd
 */
public class CrawlingWeatherNew {

    private static final Logger log = LoggerFactory.getLogger(CrawlingWeatherNew.class);

    private static final String USER_AGENT = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/86.0.4240.193 Safari/537.36";
    private static final String COOKIE = "f_city=%E9%83%91%E5%B7%9E%7C101180101%7C; Hm_lvt_080dabacb001ad3dc8b9b9049b36d43b=1546482322; Hm_lpvt_080dabacb001a";
    public static final String REFERER = "http://www.weather.com.cn/";

    public static RealTimeWeatherVo handlerWeatherData(String cityCode){
        RealTimeWeatherVo realTimeWeather = new RealTimeWeatherVo();
        // 时间
        LocalDateTime localDateTime = LocalDateTime.now();
        // 拿到数据
        String data = getRealTimeWeather(cityCode);
        // 建立treeJson
        try {
            ObjectMapper mapper = new ObjectMapper();
            JsonNode jsonNode = mapper.readTree(data);
            // 根据路径获取数据
            String cityName = jsonNode.path("cityname").asText();
            String weather = jsonNode.path("weather").asText();
            String temp = jsonNode.path("temp").asText();
            String tempf = jsonNode.path("tempf").asText();
            String wd = jsonNode.path("WD").asText();
            String ws = jsonNode.path("WS").asText();
            String sd = jsonNode.path("SD").asText();
            String wse = jsonNode.path("wse").asText();
            String qy = jsonNode.path("qy").asText();
            String njd = jsonNode.path("njd").asText();
            String rain = jsonNode.path("rain").asText();
            String rain24 = jsonNode.path("rain24h").asText();
            String aqi = jsonNode.path("aqi").asText();
            String aqiPm25 = jsonNode.path("aqi_pm25").asText();
            realTimeWeather.setWeather(weather);
            realTimeWeather.setTemp(temp);
            realTimeWeather.setTempf(tempf);
            realTimeWeather.setWd(wd);
            realTimeWeather.setWs(ws);
            realTimeWeather.setSd(sd);
            realTimeWeather.setWse(wse);
            realTimeWeather.setQy(qy);
            realTimeWeather.setNjd(njd);
            realTimeWeather.setRain(rain);
            realTimeWeather.setRain24(rain24);
            realTimeWeather.setAqi(aqi);
            realTimeWeather.setAqiPm25(aqiPm25);
            realTimeWeather.setRealTime(dateTimeToString(localDateTime));
            return realTimeWeather;
        } catch (JsonProcessingException e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 获取实时天气
     * @param cityCode 城市代码
     * @return
     *{"nameen":"qingdao","cityname":"青岛","city":"101120201","temp":"18","tempf":"64","WD":"东南风 ","wde":"SE","WS":"4级","wse":"16-24km/h",
     * "SD":"98%","time":"09:15","weather":"雨","weathere":"rain","weathercode":"d301","qy":"999","njd":"3.6km","sd":"98%","rain":"0","rain24h":"0",
     * "aqi":"16","limitnumber":"","aqi_pm25":"16","date":"11月18日(星期三)"}
     */
    public static String getRealTimeWeather(String cityCode){

        // 读取成功标志
        boolean isSuccess = false;

        // 重复次数
        int count = 10;

        // 创建http对象
        RequestConfig defaultRequestConfig = RequestConfig.custom()
                .setSocketTimeout(60000).setConnectTimeout(60000)
                .setConnectionRequestTimeout(60000)
                .build();
        CloseableHttpClient client = HttpClients.custom()
                .setDefaultRequestConfig(defaultRequestConfig).build();

        // 创建并设置URI
        URIBuilder uri = null;
        // 创建Get请求
        HttpGet get = null;
        String url = "";

        try {
            url = "http://d1.weather.com.cn/sk_2d/" + cityCode + ".html?_=" + System.currentTimeMillis();
            uri = new URIBuilder(url);
            get = new HttpGet(uri.build());
            // 设置请求头
            get.setHeader("Accept"
                    , "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8");
            get.setHeader("Accept-Encoding"
                    , "gzip, deflate");
            get.setHeader("Accept-Language"
                    , "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7,zh-TW;q=0.6");
            get.setHeader("Connection"
                    , "keep-alive");
            get.setHeader("Cache-Control"
                    , "no-cache");
            get.setHeader("Host"
                    , "d1.weather.com.cn");
            get.setHeader("Upgrade-Insecure-Requests"
                    , "1");
            get.setHeader("Cookie", COOKIE);
            get.setHeader("User-Agent", USER_AGENT);
            get.setHeader("Referer", REFERER);
        } catch (Exception e) {
            log.info("错误{}", (Object) e.getStackTrace());
        }

        //发送请求
        HttpEntity entity = null;
        InputStream is = null;
        BufferedReader br = null;
        // 创建响应对象
        CloseableHttpResponse response = null;
        String line = null;
        String sLine = null;

        String json = null;
        while (!isSuccess && count > 0){
            try {
                response = client.execute(get);
                // 获取请求结果
                if (response.getStatusLine().getStatusCode() != HttpStatus.SC_OK){
                    log.info("实时天气数据未请求成功");
                    count --;
                    continue;
                }
                entity = response.getEntity();
                is = entity.getContent();
                br = new BufferedReader(
                        new InputStreamReader(is, StandardCharsets.UTF_8)
                );
                StringBuffer sb = new StringBuffer();
                while((line = br.readLine()) != null){
                    sb.append(line);
                    sb.append("/n");
                }
                sLine = sb.toString();
                sLine = sLine.substring(sLine.indexOf("{"));
                sLine = sLine.substring(0,sLine.length()-2);
                ObjectMapper objectMapper = new ObjectMapper();
                //使用ObjectMapper对象对 User对象进行转换
                try {
                    json = objectMapper.writeValueAsString(sLine);
                } catch (JsonProcessingException e) {
                    log.info("json字符串转化异常{}", (Object) e.getStackTrace());
                }
                isSuccess = true;

            } catch (ClientProtocolException e) {
                // TODO Auto-generated catch block
                log.info("请求超时等问题:{}", (Object) e.getStackTrace());

            }catch (IOException e) {
                log.info("I/O问题:{}", (Object) e.getStackTrace());
            }finally {
                close(is,br,response,client);
            }
        }
        return sLine;
    }

//    /**
//     * 获得7天天气 老版中国天气网
//     * @param cityCode 城市代码
//     */
//    public static void getWeather7d(String cityCode){
//
//        String url = "http://www.weather.com.cn/weather/" + cityCode + ".shtml";
//        try {
//            Document doc = Jsoup.connect(url).get();
//            Elements content =  doc.getElementsByClass("con");
//            for (Element e : content) {
//                Document conDoc = Jsoup.parse(e.toString());
//                Elements cru =  conDoc.getElementsByClass("crumbs");
//                Elements sky = content.select("li[class^=sky skyid lv]");
//                Elements data = content.select("li[class^=date-item]");
//                // 地点
//                System.out.println(cru.text());
//                // weather
//                for (Element sk : sky) {
//                    System.out.println("时间" + sk.text());
//                }
//            }
//        } catch (Exception e) {
//            log.info("未知错误{}", (Object) e.getStackTrace());
//        }
//        log.info("天气查询完毕！！");
//    }

    /**
     * 关闭流
     * @param is InputStream
     * @param br BufferedReader
     * @param response  CloseableHttpResponse
     * @param client CloseableHttpClient
     */
    private static void close(InputStream is, BufferedReader br, CloseableHttpResponse response, CloseableHttpClient client){
        try {
            if (null != is){
                is.close();
            }
            if (null != br){
                br.close();
            }
            if (null != response){
                response.close();
            }
            if (null != client){
                client.close();
            }
        } catch (IOException e) {
            log.info("IO错误{}", (Object) e.getStackTrace());
        }
    }

    public static void main(String[] args) {
        RealTimeWeatherVo realTimeWeatherVo = handlerWeatherData("101120201");
        System.out.println(realTimeWeatherVo);
    }
}
