package com.xkrs.microservice.common.tool;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.xkrs.microservice.model.vo.FileServerResultVo;
import com.xkrs.microservice.util.RequestUtil;
import org.apache.http.HttpEntity;
import org.apache.http.NameValuePair;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 文件服务器工具
 * @author tajochen
 */
public class FileServerTool {

    private static final String UA = "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:89.0) Gecko/20100101 Firefox/89.0";

    /**
     * 发送管理命令到文件服务器
     * @param url 文件服务器路径
     * @param map 命令参数集
     * @return
     */
    public static FileServerResultVo postFileManage(String url, Map<String,String> map){
        Logger log = LoggerFactory.getLogger(RequestUtil.class);
        String body = "";
        // 创建httpclient对象
        CloseableHttpClient client = HttpClients.createDefault();
        // 创建post方式请求对象
        HttpPost httpPost = new HttpPost(url);
        // 装填参数
        List<NameValuePair> nvps = new ArrayList<>();
        if(map!=null){
            for (Map.Entry<String, String> entry : map.entrySet()) {
                nvps.add(new BasicNameValuePair(entry.getKey(), entry.getValue()));
            }
        }
        try {
            // 设置参数到请求对象中
            httpPost.setEntity(new UrlEncodedFormEntity(nvps, "UTF-8"));
            // 设置header报文头信息
            httpPost.setHeader("Content-type", "application/x-www-form-urlencoded");
            httpPost.setHeader("User-Agent", UA);
            httpPost.setHeader("Accept", "application");
            httpPost.setHeader("Accept-Encoding", "gzip, deflate");
            // 执行请求操作，并拿到结果（同步阻塞）
            CloseableHttpResponse response = client.execute(httpPost);
            // 获取结果实体
            HttpEntity entity = response.getEntity();
            if (entity != null) {
                // 按指定编码转换结果实体为String类型
                body = EntityUtils.toString(entity, "UTF-8");
            }
            EntityUtils.consume(entity);
            // 释放链接
            response.close();
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                client.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        FileServerResultVo fileServerResultVo = new FileServerResultVo();
        ObjectMapper mapper = new ObjectMapper();
        try {
            fileServerResultVo = mapper.readValue(body, FileServerResultVo.class);
        } catch (JsonProcessingException e) {
            e.printStackTrace();
            log.warn(e.toString());

        }
        return fileServerResultVo;
    }
}
