package com.xkrs.microservice.controller;

import com.xkrs.microservice.common.encapsulation.PromptMessageEnum;
import com.xkrs.microservice.model.entity.FarmingInfoEntity;
import com.xkrs.microservice.model.qo.FarmingInfoQo;
import com.xkrs.microservice.model.validation.FarmingInfoQoInsert;
import com.xkrs.microservice.service.FarmingInfoService;

import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Locale;
import java.util.Optional;

import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationErrorList;
import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;
import static com.xkrs.microservice.common.tool.TokenUtil.getTokenUserName;

/**
 * 农情信息表管理
 * @author tajochen
 */
@RestController
@RequestMapping("/api/farming-info")
public class FarmingInfoController {

    /**
     * 获取区域信息
     */
    Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private FarmingInfoService farmingInfoService;

    @RequestMapping(value="/get/all",method = RequestMethod.GET)
    @CrossOrigin
    public String getAllRecord() {
        Iterable<FarmingInfoEntity> list = farmingInfoService.getAllRecord();
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/dkbh",method = RequestMethod.GET)
    @CrossOrigin
    public String getByDkbh(@RequestParam("dkbh") String dkbh) {
        Iterable<FarmingInfoEntity> list = farmingInfoService.getByDkbh(dkbh);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/qxbh",method = RequestMethod.GET)
    @CrossOrigin
    public String getByQxbh(@RequestParam("qxbh") Integer qxbh) {
        Iterable<FarmingInfoEntity> list = farmingInfoService.getByQxbh(qxbh);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/zwdm",method = RequestMethod.GET)
    @CrossOrigin
    public String getByQxbhAndZwdm(@RequestParam("qxbh") Integer qxbh,@RequestParam("zwdm") Integer zwdm) {
        Iterable<FarmingInfoEntity> list = farmingInfoService.getByZwdmAndQxbh(zwdm,qxbh);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/new",method = RequestMethod.GET)
    @CrossOrigin
    public String getNewByQxbh(@RequestParam("qxbh") Integer qxbh) {
        Iterable<FarmingInfoEntity> list = farmingInfoService.getNewByQxbh(qxbh);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/user-name",method = RequestMethod.GET)
    @CrossOrigin
    public String getByUserName(@RequestParam("userName") String userName) {
        Iterable<FarmingInfoEntity> list = farmingInfoService.getByUserName(userName);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/add",method = RequestMethod.POST)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_general_user','auth_administor','auth_farm_user')")
    @CrossOrigin
    public String dataAdd(@Validated({FarmingInfoQoInsert.class}) @RequestBody FarmingInfoQo farmingInfoQo,
                          BindingResult bindingResult,@RequestHeader(value="Authorization") String token) {
        // 验证数据合法性
        if(bindingResult.hasErrors()){
            return outputEncapsulationErrorList(bindingResult.getFieldErrors(),locale);
        }
        // 获取当前用户名
        String userName = getTokenUserName(token);
        farmingInfoService.add(farmingInfoQo,userName);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

    @RequestMapping(value="/delete",method = RequestMethod.DELETE)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_administor')")
    @CrossOrigin
    public String dataDelete(@RequestParam("id") Integer id) {
        Optional<FarmingInfoEntity> typicalPlotEntity = farmingInfoService.getById(id);
        if(typicalPlotEntity.isEmpty()){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"参数错误",locale);
        }
        farmingInfoService.delete(id);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

}
