package com.xkrs.microservice.controller;

import com.xkrs.microservice.common.encapsulation.PromptMessageEnum;
import com.xkrs.microservice.model.entity.FileDocumentEntity;
import com.xkrs.microservice.model.qo.FileDocumentQo;
import com.xkrs.microservice.model.validation.FileDocumentQoInsert;
import com.xkrs.microservice.model.vo.FileServerResultVo;
import com.xkrs.microservice.service.FileDocumentService;
import com.xkrs.microservice.service.FileServerService;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Locale;
import java.util.Optional;

import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationErrorList;
import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;
import static com.xkrs.microservice.common.tool.TokenUtil.getTokenUserName;
import static com.xkrs.microservice.util.NumberUtil.isStrNumeric;

/**
 * 文档管理服务
 * @author tajochen
 */
@RestController
@RequestMapping("/api/document")
public class FileDocumentController {

    /**
     * 获取区域信息
     */
    Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private FileDocumentService fileDocumentService;

    @Resource
    private FileServerService fileServerService;

    @RequestMapping(value="/get/all",method = RequestMethod.GET)
    public String getAllFiles() {
        Iterable<FileDocumentEntity> list = fileDocumentService.getAllFile();
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/add",method = RequestMethod.POST)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_general_user','auth_administor')")
    @CrossOrigin
    public String fileUpload(@Validated({FileDocumentQoInsert.class}) @RequestBody FileDocumentQo fileDocumentQo,
            BindingResult bindingResult,@RequestHeader(value="Authorization") String token) {
        // 验证数据合法性
        if(bindingResult.hasErrors()){
            return outputEncapsulationErrorList(bindingResult.getFieldErrors(),locale);
        }
        // 获取当前用户名
        String userName = getTokenUserName(token);
        fileDocumentService.add(fileDocumentQo,userName);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

    @RequestMapping(value="/delete",method = RequestMethod.DELETE)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_administor')")
    @CrossOrigin
    public String fileDelete(@RequestParam("id") Integer id) {
        Optional <FileDocumentEntity> sf = fileDocumentService.getById(id);
        if(sf.isEmpty()){
            return outputEncapsulationObject(PromptMessageEnum.DATA_WRONG,"指定id文件不存在",locale);
        }
        try {
            FileServerResultVo fileServerResultVo = fileServerService.deleteFile(sf.get().getMd5(),"");
            fileDocumentService.delete(id);
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS,fileServerResultVo,locale);
        } catch (Exception e) {
            e.printStackTrace();
            return outputEncapsulationObject(PromptMessageEnum.PROCESS_FAIL,"文件服务器出错",locale);
        }
    }
}
