package com.xkrs.microservice.controller;

import com.xkrs.microservice.common.encapsulation.PromptMessageEnum;
import com.xkrs.microservice.model.entity.HydrologicalStationEntity;
import com.xkrs.microservice.model.qo.HydrologicalStationQo;
import com.xkrs.microservice.model.validation.HydrologicalStationQoInsert;
import com.xkrs.microservice.service.HydrologicalStationService;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.Locale;

import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationErrorList;
import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;
import static com.xkrs.microservice.util.DateTimeUtil.timeMillisToTime;

/**
 * 水文站点数据服务管理
 * @author tajochen
 */
@RestController
@RequestMapping("/api/hydrological-station")
public class HydrologicalStationController {

    /**
     * 获取区域信息
     */
    Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private HydrologicalStationService hydrologicalStationService;

    @RequestMapping(value="/get/all",method = RequestMethod.GET)
    public String getAllFiles() {
        Iterable<HydrologicalStationEntity> list = hydrologicalStationService.getAllRecord();
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/time",method = RequestMethod.GET)
    public String getByTime(@RequestParam("sTimeTs") Long sTimeTs,@RequestParam("eTimeTs") Long eTimeTs) {
        LocalDateTime sTime = timeMillisToTime(sTimeTs);
        LocalDateTime eTime = timeMillisToTime(eTimeTs);
        Iterable<HydrologicalStationEntity> list = hydrologicalStationService.getByTime(sTime,eTime);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/add",method = RequestMethod.POST)
    @CrossOrigin
    public String addRecord(@Validated({HydrologicalStationQoInsert.class}) @RequestBody HydrologicalStationQo hydrologicalStationQo,
            BindingResult bindingResult) {
        // 验证数据合法性
        if(bindingResult.hasErrors()){
            return outputEncapsulationErrorList(bindingResult.getFieldErrors(),locale);
        }
        hydrologicalStationService.add(hydrologicalStationQo);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

    @RequestMapping(value="/delete",method = RequestMethod.DELETE)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_general_user','auth_administor')")
    @CrossOrigin
    public String deleteRecord(@RequestParam("id") Integer id) {
        int res = hydrologicalStationService.delete(id);
        if(res!=0){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"id 不存在",locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }
}
