package com.xkrs.microservice.controller;

import com.xkrs.microservice.common.encapsulation.PromptMessageEnum;
import com.xkrs.microservice.model.entity.IrrigationCheckEntity;
import com.xkrs.microservice.model.qo.IrrigationCheckQo;
import com.xkrs.microservice.model.validation.IrrigationCheckQoInsert;
import com.xkrs.microservice.service.IrrigationCheckService;

import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.Locale;
import java.util.Optional;

import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationErrorList;
import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;
import static com.xkrs.microservice.common.tool.TokenUtil.getTokenUserName;
import static com.xkrs.microservice.util.DateTimeUtil.timeMillisToDate;
import static com.xkrs.microservice.util.DateTimeUtil.timeMillisToTime;

/**
 * 灌溉核查表管理
 * @author tajochen
 */
@RestController
@RequestMapping("/api/irrigation-check")
public class IrrigationCheckController {

    /**
     * 获取区域信息
     */
    Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private IrrigationCheckService irrigationCheckService;

    @RequestMapping(value="/get/all",method = RequestMethod.GET)
    @CrossOrigin
    public String getAllRecord() {
        Iterable<IrrigationCheckEntity> list = irrigationCheckService.getAllRecord();
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/ggbh",method = RequestMethod.GET)
    @CrossOrigin
    public String getByGgbh(@RequestParam("ggbh") String ggbh) {
        Optional<IrrigationCheckEntity> list = irrigationCheckService.getByGgbh(ggbh);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/qxbh",method = RequestMethod.GET)
    @CrossOrigin
    public String getQxbh(@RequestParam("qxbh") Integer qxbh) {
        Iterable<IrrigationCheckEntity> list = irrigationCheckService.getByQxbh(qxbh);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/dkbh",method = RequestMethod.GET)
    @CrossOrigin
    public String getByDkbh(@RequestParam("dkbh") String dkbh) {
        Iterable<IrrigationCheckEntity> list = irrigationCheckService.getByDkbh(dkbh);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/time",method = RequestMethod.GET)
    @CrossOrigin
    public String getByQxbhAndCreateTimeBetween(@RequestParam("qxdm") Integer qxdm,@RequestParam("sTimeTs") Long sTimeTs,@RequestParam("eTimeTs") Long eTimeTs) {
        if(sTimeTs > eTimeTs){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"",locale);
        }
        LocalDateTime sTime = timeMillisToTime(sTimeTs);
        LocalDateTime eTime = timeMillisToTime(eTimeTs);
        Iterable<IrrigationCheckEntity> list = irrigationCheckService.getByQxbhAndCreateTimeBetween(qxdm,sTime,eTime);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/user-name",method = RequestMethod.GET)
    @CrossOrigin
    public String getByUserName(@RequestParam("userName") String userName) {
        Iterable<IrrigationCheckEntity> list = irrigationCheckService.getByUserName(userName);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/add",method = RequestMethod.POST)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_general_user','auth_administor')")
    @CrossOrigin
    public String dataAdd(@Validated({IrrigationCheckQoInsert.class}) @RequestBody IrrigationCheckQo irrigationCheckQo,
                          BindingResult bindingResult,@RequestHeader(value="Authorization") String token) {
        // 验证数据合法性
        if(bindingResult.hasErrors()){
            return outputEncapsulationErrorList(bindingResult.getFieldErrors(),locale);
        }
        // 获取当前用户名
        String userName = getTokenUserName(token);
        irrigationCheckService.add(irrigationCheckQo,userName);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

    @RequestMapping(value="/delete",method = RequestMethod.DELETE)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_administor')")
    @CrossOrigin
    public String dataDelete(@RequestParam("id") Integer id) {
        Optional<IrrigationCheckEntity> typicalPlotIrrigationEntity = irrigationCheckService.getById(id);
        if(typicalPlotIrrigationEntity.isEmpty()){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"参数错误",locale);
        }
        irrigationCheckService.delete(id);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

}
