package com.xkrs.microservice.controller;

import com.xkrs.microservice.common.encapsulation.PromptMessageEnum;
import com.xkrs.microservice.model.vo.ShpCityVo;
import com.xkrs.microservice.model.vo.ShpCountyVo;
import com.xkrs.microservice.service.AdministrativeDivisionService;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.Locale;

import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;
import static com.xkrs.microservice.util.NumberUtil.isStrAdmCode;

/**
 * 行政区划服务
 * @author tajochen
 */
@RestController
@RequestMapping("/api/adm")
public class ShpAdmController {

    /**
     * 获取区域信息
     */
    Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private AdministrativeDivisionService administrativeDivisionService;

    @RequestMapping(value="/city/get/all",method = RequestMethod.GET)
    public String getAllCity() {
        Iterable<ShpCityVo> list = administrativeDivisionService.getAllCity();
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/city/get/province-code",method = RequestMethod.GET)
    public String getAllCityByProvinceCode(@RequestParam(value="provinceCode") String provinceCode) {
        if(!isStrAdmCode(provinceCode)){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"",locale);
        }
        Iterable<ShpCityVo> list = administrativeDivisionService.getAllCityByProvinceCode(Integer.valueOf(provinceCode));
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/city/get/city-code",method = RequestMethod.GET)
    public String getAllCityCityCode(@RequestParam(value="cityCode") String cityCode) {
        if(!isStrAdmCode(cityCode)){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"",locale);
        }
        ShpCityVo res = administrativeDivisionService.getCityByCityCode(Integer.valueOf(cityCode));
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,res,locale);
    }

    @RequestMapping(value="/county/get/all",method = RequestMethod.GET)
    public String getAllCounty() {
        Iterable<ShpCountyVo> list = administrativeDivisionService.getAllCounty();
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/county/get/province-code",method = RequestMethod.GET)
    public String getAllCountyByProvinceCode(@RequestParam(value="provinceCode") String provinceCode) {
        if(!isStrAdmCode(provinceCode)){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"",locale);
        }
        Iterable<ShpCountyVo> list = administrativeDivisionService.getAllCountyByProvinceCode(
                Integer.valueOf(provinceCode));
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/county/get/city-code",method = RequestMethod.GET)
    public String getAllCountyByCityCode(@RequestParam(value="cityCode") String cityCode) {
        if(!isStrAdmCode(cityCode)){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"",locale);
        }
        Iterable<ShpCountyVo> list = administrativeDivisionService.getAllCountyByCityCode(Integer.valueOf(cityCode));
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/county/get/county-code",method = RequestMethod.GET)
    public String getAllCountyByCountyCode(@RequestParam(value="countyCode") String countyCode) {
        if(!isStrAdmCode(countyCode)){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"",locale);
        }
        ShpCountyVo res = administrativeDivisionService.getCountyByCountyCode(Integer.valueOf(countyCode));
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,res,locale);
    }

}
