package com.xkrs.microservice.controller;

import com.xkrs.microservice.common.encapsulation.PromptMessageEnum;
import com.xkrs.microservice.model.entity.TypicalFarmerEntity;
import com.xkrs.microservice.model.qo.TypicalFarmerQo;
import com.xkrs.microservice.model.validation.TypicalFarmerQoInsert;
import com.xkrs.microservice.model.validation.TypicalFarmerQoUpdate;
import com.xkrs.microservice.service.SysUserService;
import com.xkrs.microservice.service.TypicalFarmerService;

import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Locale;
import java.util.Optional;

import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationErrorList;
import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * 典型区农户表管理
 * @author tajochen
 */
@RestController
@RequestMapping("/api/typical-farmer")
public class TypicalFarmerController {

    /**
     * 获取区域信息
     */
    Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private TypicalFarmerService typicalFarmerService;

    @Resource
    private SysUserService sysUserService;

    @RequestMapping(value="/get/all",method = RequestMethod.GET)
    @CrossOrigin
    public String getAllRecord() {
        Iterable<TypicalFarmerEntity> list = typicalFarmerService.getAllRecord();
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/xzdm",method = RequestMethod.GET)
    @CrossOrigin
    public String getByTownCode(@RequestParam("xzdm") String xzdm) {
        Iterable<TypicalFarmerEntity> list = typicalFarmerService.getByTownCode(xzdm);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/qxdm",method = RequestMethod.GET)
    @CrossOrigin
    public String getByCountyCode(@RequestParam("qxdm") Integer qxdm) {
        Iterable<TypicalFarmerEntity> list = typicalFarmerService.getByCountyCode(qxdm);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/lxr",method = RequestMethod.GET)
    @CrossOrigin
    public String getByLxr(@RequestParam("lxr") String lxr) {
        Iterable<TypicalFarmerEntity> list = typicalFarmerService.getByLxr(lxr);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/user-name",method = RequestMethod.GET)
    @CrossOrigin
    public String getByUserName(@RequestParam("userName") String userName) {
        Optional<TypicalFarmerEntity> obj = typicalFarmerService.getByTel(userName);
        if(obj.isEmpty()){
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
        } else {
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS,obj.get(),locale);
        }
    }

    @RequestMapping(value="/add",method = RequestMethod.POST)
    @CrossOrigin
    public String dataAdd(@Validated({TypicalFarmerQoInsert.class}) @RequestBody TypicalFarmerQo typicalFarmerQo,
                          BindingResult bindingResult) {
        // 验证数据合法性
        if(bindingResult.hasErrors()){
            return outputEncapsulationErrorList(bindingResult.getFieldErrors(),locale);
        }
        // 验证用户名是否重复
        if(!sysUserService.checkUserName(typicalFarmerQo.getTel())){
            return outputEncapsulationObject(PromptMessageEnum.USER_ALREADY_EXIST,"用户名已存在！",locale);
        }
        // 添加新用户
        typicalFarmerService.add(typicalFarmerQo,typicalFarmerQo.getTel());
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

    @RequestMapping(value="/update",method = RequestMethod.POST)
    @CrossOrigin
    public String dataUpdate(@Validated({TypicalFarmerQoUpdate.class}) @RequestBody TypicalFarmerQo typicalFarmerQo,
                          BindingResult bindingResult) {
        // 验证数据合法性
        if(bindingResult.hasErrors()){
            return outputEncapsulationErrorList(bindingResult.getFieldErrors(),locale);
        }
        // 验证用户名是否存在
        if(sysUserService.checkUserName(typicalFarmerQo.getTel())){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"用户名不存在！",locale);
        }
        // 添加新用户
        typicalFarmerService.update(typicalFarmerQo);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

    @RequestMapping(value="/delete",method = RequestMethod.DELETE)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_administor')")
    @CrossOrigin
    public String dataDelete(@RequestParam("id") Integer id) {
        Optional<TypicalFarmerEntity> typicalPlotEntity = typicalFarmerService.getById(id);
        if(typicalPlotEntity.isEmpty()){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"参数错误",locale);
        }
        typicalFarmerService.delete(id);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

}
