package com.xkrs.microservice.controller;

import com.xkrs.microservice.common.encapsulation.PromptMessageEnum;
import com.xkrs.microservice.model.entity.TypicalPlotEntity;
import com.xkrs.microservice.model.qo.TypicalPlotQo;
import com.xkrs.microservice.model.validation.TypicalPlotQoInsert;
import com.xkrs.microservice.model.validation.TypicalPlotQoUpdate;
import com.xkrs.microservice.service.TypicalPlotService;

import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Locale;
import java.util.Optional;

import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationErrorList;
import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;
import static com.xkrs.microservice.common.tool.TokenUtil.getTokenUserName;

/**
 * 典型区地块管理
 * @author tajochen
 */
@RestController
@RequestMapping("/api/typical-plot")
public class TypicalPlotController {

    /**
     * 获取区域信息
     */
    Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private TypicalPlotService typicalPlotService;

    @RequestMapping(value="/get/all",method = RequestMethod.GET)
    @CrossOrigin
    public String getAllRecord() {
        Iterable<TypicalPlotEntity> list = typicalPlotService.getAllRecord();
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/qxdm",method = RequestMethod.GET)
    @CrossOrigin
    public String getByCountyCode(@RequestParam("qxdm") Integer qxdm) {
        Iterable<TypicalPlotEntity> list = typicalPlotService.getByCountyCode(qxdm);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/xzdm",method = RequestMethod.GET)
    @CrossOrigin
    public String getByTownCode(@RequestParam("xzdm") String xzdm) {
        Iterable<TypicalPlotEntity> list = typicalPlotService.getByTownCode(xzdm);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/dkbh",method = RequestMethod.GET)
    @CrossOrigin
    public String getByDkbh(@RequestParam("dkbh") String dkbh) {
        Optional<TypicalPlotEntity> res = typicalPlotService.getByDkbh(dkbh);
        if(res.isPresent()){
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS,res.get(),locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.DATA_WRONG,"dkbh 不存在",locale);
    }

    @RequestMapping(value="/get/lxr",method = RequestMethod.GET)
    @CrossOrigin
    public String getByLxr(@RequestParam("lxr") String lxr) {
        Iterable<TypicalPlotEntity> list = typicalPlotService.getByLxr(lxr);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/tel",method = RequestMethod.GET)
    @CrossOrigin
    public String getByTel(@RequestParam("tel") String tel) {
        Iterable<TypicalPlotEntity> list = typicalPlotService.getByTel(tel);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/user-name",method = RequestMethod.GET)
    @CrossOrigin
    public String getByUserName(@RequestParam("userName") String userName) {
        Iterable<TypicalPlotEntity> list = typicalPlotService.getByTel(userName);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/update",method = RequestMethod.POST)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_general_user','auth_administor')")
    @CrossOrigin
    public String dataUpdate(@Validated({TypicalPlotQoUpdate.class}) @RequestBody TypicalPlotQo typicalPlotQo,
                          BindingResult bindingResult,@RequestHeader(value="Authorization") String token) {
        // 验证数据合法性
        if(bindingResult.hasErrors()){
            return outputEncapsulationErrorList(bindingResult.getFieldErrors(),locale);
        }
        // 获取当前用户名
        String userName = getTokenUserName(token);
        typicalPlotService.update(typicalPlotQo,userName);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

    @RequestMapping(value="/add",method = RequestMethod.POST)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_general_user','auth_administor','auth_farm_user')")
    @CrossOrigin
    public String dataAdd(@Validated({TypicalPlotQoInsert.class}) @RequestBody TypicalPlotQo typicalPlotQo,
                          BindingResult bindingResult,@RequestHeader(value="Authorization") String token) {
        // 验证数据合法性
        if(bindingResult.hasErrors()){
            return outputEncapsulationErrorList(bindingResult.getFieldErrors(),locale);
        }
        // 监测地块编号是否存在
        Optional<TypicalPlotEntity> typicalPlotEntity = typicalPlotService.getByDkbh(typicalPlotQo.getDkbh());
        if(typicalPlotEntity.isPresent()){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"地块编号已存在",locale);
        }
        // 获取当前用户名
        String userName = getTokenUserName(token);
        typicalPlotService.add(typicalPlotQo,userName);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

    @RequestMapping(value="/delete",method = RequestMethod.DELETE)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_general_user','auth_administor','auth_farm_user')")
    @CrossOrigin
    public String dataDelete(@RequestParam("id") Integer id) {
        Optional<TypicalPlotEntity> typicalPlotEntity = typicalPlotService.getById(id);
        if(typicalPlotEntity.isEmpty()){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"参数错误",locale);
        }
        typicalPlotService.delete(id);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

}
