package com.xkrs.microservice.controller;

import com.xkrs.microservice.common.encapsulation.PromptMessageEnum;
import com.xkrs.microservice.model.entity.TypicalPlotIrrigationEntity;
import com.xkrs.microservice.model.qo.TypicalPlotIrrigationQo;
import com.xkrs.microservice.model.validation.TypicalPlotIrrigationQoInsert;
import com.xkrs.microservice.service.TypicalPlotIrrigationService;

import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;
import java.util.Locale;
import java.util.Optional;

import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationErrorList;
import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;
import static com.xkrs.microservice.common.tool.TokenUtil.getTokenUserName;
import static com.xkrs.microservice.util.DateTimeUtil.timeMillisToTime;

/**
 * 灌溉信息表管理
 * @author tajochen
 */
@RestController
@RequestMapping("/api/typical-plot-irrigation")
public class TypicalPlotIrrigationController {

    /**
     * 获取区域信息
     */
    Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private TypicalPlotIrrigationService typicalPlotIrrigationService;

    @RequestMapping(value="/get/all",method = RequestMethod.GET)
    @CrossOrigin
    public String getAllRecord() {
        Iterable<TypicalPlotIrrigationEntity> list = typicalPlotIrrigationService.getAllRecord();
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/ggbh",method = RequestMethod.GET)
    @CrossOrigin
    public String getByGgbh(@RequestParam("ggbh") String ggbh) {
        Optional<TypicalPlotIrrigationEntity> list = typicalPlotIrrigationService.getByGgbh(ggbh);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/qxbh",method = RequestMethod.GET)
    @CrossOrigin
    public String getByQxbh(@RequestParam("qxbh") Integer qxbh) {
        Iterable<TypicalPlotIrrigationEntity> list = typicalPlotIrrigationService.getByQxbh(qxbh);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/dkbh",method = RequestMethod.GET)
    @CrossOrigin
    public String getByDkbh(@RequestParam("dkbh") String dkbh) {
        Iterable<TypicalPlotIrrigationEntity> list = typicalPlotIrrigationService.getByDkbh(dkbh);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/user-name",method = RequestMethod.GET)
    @CrossOrigin
    public String getByUserName(@RequestParam("userName") String userName) {
        Iterable<TypicalPlotIrrigationEntity> list = typicalPlotIrrigationService.getByUserName(userName);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/condition",method = RequestMethod.GET)
    @CrossOrigin
    public String getByCondition(@RequestParam("xzbh") String xzbh,
                                 @RequestParam("cropCode") Integer cropCode,
                                 @RequestParam("sTimeTs") Long sTime,
                                 @RequestParam("eTimeTs") Long eTime) {
        List<TypicalPlotIrrigationEntity> list = typicalPlotIrrigationService.getAllByCondition(xzbh,cropCode,sTime,eTime);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/time",method = RequestMethod.GET)
    @CrossOrigin
    public String getByQxbhAndCreateTimeBetween(@RequestParam("qxdm") Integer qxdm,@RequestParam("sTimeTs") Long sTimeTs,@RequestParam("eTimeTs") Long eTimeTs) {
        if(sTimeTs > eTimeTs){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"",locale);
        }
        LocalDateTime sTime = timeMillisToTime(sTimeTs);
        LocalDateTime eTime = timeMillisToTime(eTimeTs);
        Iterable<TypicalPlotIrrigationEntity> list = typicalPlotIrrigationService.findAllByQxbhAndStrtimeBetween(qxdm,sTime,eTime);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/add",method = RequestMethod.POST)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_general_user','auth_administor','auth_farm_user')")
    @CrossOrigin
    public String dataAdd(@Validated({TypicalPlotIrrigationQoInsert.class}) @RequestBody TypicalPlotIrrigationQo typicalPlotIrrigationQo,
                          BindingResult bindingResult,@RequestHeader(value="Authorization") String token) {
        // 验证数据合法性
        if(bindingResult.hasErrors()){
            return outputEncapsulationErrorList(bindingResult.getFieldErrors(),locale);
        }
        // 验证灌溉编号是否存在
        Optional<TypicalPlotIrrigationEntity> typicalPlotIrrigationEntity = typicalPlotIrrigationService.getByGgbh(typicalPlotIrrigationQo.getGgbh());
        if(typicalPlotIrrigationEntity.isPresent()){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"灌溉编号重复！",locale);
        }
        // 获取当前用户名
        String userName = getTokenUserName(token);
        typicalPlotIrrigationService.add(typicalPlotIrrigationQo,userName);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

    @RequestMapping(value="/delete",method = RequestMethod.DELETE)
    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_administor')")
    @CrossOrigin
    public String dataDelete(@RequestParam("id") Integer id) {
        Optional<TypicalPlotIrrigationEntity> typicalPlotIrrigationEntity = typicalPlotIrrigationService.getById(id);
        if(typicalPlotIrrigationEntity.isEmpty()){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"参数错误",locale);
        }
        typicalPlotIrrigationService.delete(id);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

}
