package com.xkrs.microservice.controller;

import com.xkrs.microservice.common.encapsulation.PromptMessageEnum;
import com.xkrs.microservice.model.vo.ForecastWeather7DayVo;
import com.xkrs.microservice.model.vo.RealTimeWeatherVo;
import com.xkrs.microservice.service.MeteorologicalService;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.Locale;

import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;
import static com.xkrs.microservice.util.NumberUtil.isStrAdmCode;

/**
 * 行政区划气象站点服务
 * @author tajochen
 */
@RestController
@RequestMapping("/api/weather")
public class WeatherStationController {

    /**
     * 获取区域信息
     */
    Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private MeteorologicalService meteorologicalService;

    @RequestMapping(value="/get/now",method = RequestMethod.GET)
    public String getWeatherNowByAdmCode(@RequestParam(value="admCode") String admCode) {
        if(!isStrAdmCode(admCode)){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"",locale);
        }
        RealTimeWeatherVo res = meteorologicalService.getWeatherNowByAdmCode(Integer.valueOf(admCode));
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,res,locale);
    }

    @RequestMapping(value="/get/forecast",method = RequestMethod.GET)
    public String getWeatherForecastByAdmCode(@RequestParam(value="admCode") String admCode) {
        if(!isStrAdmCode(admCode)){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"",locale);
        }
        ForecastWeather7DayVo res = meteorologicalService.getWeatherForecastByAdmCode(Integer.valueOf(admCode));
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,res,locale);
    }

}
