package com.xkrs.microservice.dao;

import com.xkrs.microservice.model.entity.CropClassifyRecordEntity;
import org.springframework.data.jpa.repository.JpaRepository;

import java.time.LocalDate;

/**
 * CropClassifyRecordDao
 * @author tajochen
 */
public interface CropClassifyRecordDao extends JpaRepository<CropClassifyRecordEntity,Integer> {

    /**
     * 获取指定行政区划代码
     * @param countyCode 行政区划代码
     * @return
     */
    Iterable<CropClassifyRecordEntity> findByCountyCode(Integer countyCode);

    /**
     * 获取指定街道代码
     * @param townCode 街道代码
     * @param startDate 开始日期
     * @param endDate 结束日期
     * @return
     */
    Iterable<CropClassifyRecordEntity> findByTownCodeAndCropDateBetween(String townCode,LocalDate startDate,LocalDate endDate);

    /**
     * 获取指定街道代码
     * @param townCode 街道代码
     * @param cropCode 作物代码
     * @param startDate 开始日期
     * @param endDate 结束日期
     * @return
     */
    Iterable<CropClassifyRecordEntity> findByTownCodeAndCropCodeAndCropDateBetween(String townCode,Integer cropCode ,LocalDate startDate,LocalDate endDate);

    /**
     * 获取指定行政区划代码和指定日期段
     * @param countyCode 行政区划代码
     * @param startDate 开始日期
     * @param endDate 结束日期
     * @return
     */
    Iterable<CropClassifyRecordEntity> findByCountyCodeAndCropDateBetween(Integer countyCode,LocalDate startDate,LocalDate endDate);

}
