package com.xkrs.microservice.dao;

import com.xkrs.microservice.model.entity.FarmingInfoEntity;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;

/**
 * FarmingInfoDao
 * @author tajochen
 */
public interface FarmingInfoDao extends JpaRepository<FarmingInfoEntity,Integer> {

    /**
     * 查找农情信息根据地块编号
     * @param dkbh 地块编号
     * @return
     */
    Iterable<FarmingInfoEntity> findAllByDkbh(String dkbh);

    /**
     * 查找农情信息根据作物代码，区县编号
     * @param zwbh 作物编号
     * @param qxbh 区县编号
     * @return
     */
    Iterable<FarmingInfoEntity> findAllByZwdmAndQxbh(Integer zwbh,Integer qxbh);

    /**
     * 查找农情信息根据区县编号
     * @param qxbh 区县编号
     * @return
     */
    Iterable<FarmingInfoEntity> findAllByQxbh(Integer qxbh);

    /**
     * 查找最新农情信息根据区县编号
     * @param qxbh 区县编号
     * @return
     */
    @Query(value = "SELECT * FROM farming_info A WHERE A.create_time = ( SELECT MAX ( B.create_time ) " +
            "FROM farming_info B WHERE A.dkbh = B.dkbh ) AND A.qxbh = :qxbh", nativeQuery = true)
    Iterable<FarmingInfoEntity> findNewAllByQxbh(Integer qxbh);

    /**
     * 查找农情信息根据姓名
     * @param userName 联系人姓名
     * @return
     */
    Iterable<FarmingInfoEntity> findAllByAddUserName(String userName);

}
