package com.xkrs.microservice.dao;

import com.xkrs.microservice.model.entity.IrrigationCheckEntity;
import org.springframework.data.jpa.repository.JpaRepository;

import java.time.LocalDateTime;
import java.util.Optional;

/**
 * IrrigationCheckDao
 * @author tajochen
 */
public interface IrrigationCheckDao extends JpaRepository<IrrigationCheckEntity,Integer> {

    /**
     * 查找灌溉核查结果根据灌溉编号
     * @param ggbh 灌溉编号
     * @return
     */
    Optional<IrrigationCheckEntity> findByGgbh(String ggbh);

    /**
     * 查找灌溉核查结果根据区县编号
     * @param qxbh 区县编号
     * @return
     */
    Iterable<IrrigationCheckEntity> findAllByQxbh(Integer qxbh);

    /**
     * 查找灌溉核查结果根据地块编号
     * @param dkbh 地块编号
     * @return
     */
    Iterable<IrrigationCheckEntity> findAllByDkbh(String dkbh);

    /**
     * 查找灌溉核查结果根据区县编号和时间
     * @param qxbh 区县编号
     * @param sTime 开始时间
     * @param eTime 结束时间
     * @return
     */
    Iterable<IrrigationCheckEntity> findAllByQxbhAndCreateTimeBetween(Integer qxbh,LocalDateTime sTime,LocalDateTime eTime);

    /**
     * 查找灌溉核查结果用户名
     * @param userName 用户名
     * @return
     */
    Iterable<IrrigationCheckEntity> findByAddUserName(String userName);

}
