package com.xkrs.microservice.dao;

import com.xkrs.microservice.model.entity.IrrigationSarRecordEntity;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;

import java.time.LocalDate;

/**
 * IrrigationSarRecordDao
 * @author tajochen
 */
public interface IrrigationSarRecordDao extends JpaRepository<IrrigationSarRecordEntity,Integer> {

    /**
     * 获取指定行政区划代码
     * @param countyCode 区县代码
     * @return
     */
    Iterable<IrrigationSarRecordEntity> findByCountyCode(Integer countyCode);

    /**
     * 获取指定街道代码
     * @param townCode 街道代码
     * @param startDate 开始日期
     * @param endDate 结束日期
     * @return
     */
    Iterable<IrrigationSarRecordEntity> findByTownCodeAndIrrigationDateBetween(String townCode,LocalDate startDate,LocalDate endDate);

    /**
     * 获取指定数据动态多条件
     * @param townCode 街道代码
     * @param startDate 开始日期
     * @param endDate 结束日期
     * @return
     */
    @Query(value = "SELECT * FROM irrigation_sar_record WHERE CASE WHEN ( :townCode ) <> '' " +
            "THEN town_code =  :townCode ELSE 1 = 1 END " +
            "AND irrigation_date <= :endDate AND irrigation_date >= :startDate ; ", nativeQuery = true)
    Iterable<IrrigationSarRecordEntity> getAllByCondition(String townCode,LocalDate startDate,LocalDate endDate);

    /**
     * 获取指定行政区划代码和指定日期段
     * @param countyCode 行政区划代码
     * @param startDate 开始日期
     * @param endDate 结束日期
     * @return
     */
    Iterable<IrrigationSarRecordEntity> findByCountyCodeAndIrrigationDateBetween(Integer countyCode,LocalDate startDate,LocalDate endDate);

}
