package com.xkrs.microservice.dao;

import com.xkrs.microservice.model.entity.ShpCityEntity;
import com.xkrs.microservice.model.vo.ShpCityVo;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;

import java.util.List;

/**
 * ShpCityDao 表实体类
 * @author tajochen
 */
public interface ShpCityDao extends JpaRepository<ShpCityEntity,Integer> {

    /**
     * 查找所有地级市
     * @return
     */
    @Query(value = "select new com.xkrs.microservice.model.vo.ShpCityVo (city.id,city.code,city.name,city.proCode," +
            "city.proName,city.shapeArea,city.center) " +
            "from ShpCityEntity city ")
    List<ShpCityVo> selectAllCity();

    /**
     * 查找所有地级市根据省级代码
     * @param proCode 省级代码
     * @return
     */
    @Query(value = "select new com.xkrs.microservice.model.vo.ShpCityVo (city.id,city.code,city.name,city.proCode," +
            "city.proName,city.shapeArea,city.center) " +
            "from ShpCityEntity city where city.proCode = :proCode")
    List<ShpCityVo> selectAllCityByProvinceCode(@Param("proCode") Integer proCode);

    /**
     * 查找指定地级市根据地级市代码
     * @param code 地级市代码
     * @return
     */
    @Query(value = "select new com.xkrs.microservice.model.vo.ShpCityVo (city.id,city.code,city.name,city.proCode," +
            "city.proName,city.shapeArea,city.center) " +
            "from ShpCityEntity city where city.code = :code")
    ShpCityVo selectCityByCityCode(@Param("code") Integer code);

}
