package com.xkrs.microservice.dao;

import com.xkrs.microservice.model.entity.ShpCountyEntity;
import com.xkrs.microservice.model.vo.ShpCountyVo;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;

import java.util.List;

/**
 * ShpCountyDao 表实体类
 * @author tajochen
 */
public interface ShpCountyDao extends JpaRepository<ShpCountyEntity,Integer> {

    /**
     * 查找所有区县
     * @return
     */
    @Query(value = "select new com.xkrs.microservice.model.vo.ShpCountyVo (county.id,county.code,county.name," +
            "county.cityCode,county.cityName,county.proCode,county.proName,county.shapeArea,county.center," +
            "county.memo) " +
            "from ShpCountyEntity county")
    List<ShpCountyVo> selectAllCounty();

    /**
     * 查找所有区县根据省级代码
     * @param proCode 省级代码
     * @return
     */
    @Query(value = "select new com.xkrs.microservice.model.vo.ShpCountyVo (county.id,county.code,county.name," +
            "county.cityCode,county.cityName,county.proCode,county.proName,county.shapeArea,county.center," +
            "county.memo) " +
            "from ShpCountyEntity county where county.proCode= :proCode")
    List<ShpCountyVo> selectAllCountyByProvinceCode(@Param("proCode") Integer proCode);

    /**
     * 查找所有区县根据市级代码
     * @param cityCode 地级市代码
     * @return
     */
    @Query(value = "select new com.xkrs.microservice.model.vo.ShpCountyVo (county.id,county.code,county.name," +
            "county.cityCode,county.cityName,county.proCode,county.proName,county.shapeArea,county.center," +
            "county.memo) " +
            "from ShpCountyEntity county where county.cityCode= :cityCode")
    List<ShpCountyVo> selectAllCountyByCityCode(@Param("cityCode") Integer cityCode);

    /**
     * 查找指定区县根据区县代码
     * @param code 区县代码
     * @return
     */
    @Query(value = "select new com.xkrs.microservice.model.vo.ShpCountyVo (county.id,county.code,county.name," +
            "county.cityCode,county.cityName,county.proCode,county.proName,county.shapeArea,county.center," +
            "county.memo) " +
            "from ShpCountyEntity county where county.code= :code")
    ShpCountyVo selectCountyByCountyCode(@Param("code") Integer code);
}
