package com.xkrs.microservice.dao;

import com.xkrs.microservice.model.entity.SysUserEntity;
import com.xkrs.microservice.model.vo.SysUserVo;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;

import java.util.List;

/**
 * SysUserDao
 * @author tajochen
 */
public interface SysUserDao extends JpaRepository<SysUserEntity,Integer> {

    /**
     * 获取指定userName
     * @param userName 用户名
     * @return
     */
    SysUserEntity findByUserName(String userName);


    /**
     * 获取指定用户Vo（未删除、已激活）
     * @param userName 用户名
     * @return
     */
    @Query(value = "select new com.xkrs.microservice.model.vo.SysUserVo (u.id, u.userName, u.nickName,u.realName, u.userCode, " +
            "u.sex, u.telephone, u.email, u.admCode, u.address,u.birthday,u.signature,r.roleNameZh, u.portraitId," +
            "u.statusCode,u.addTime,u.lastEntryTime,u.lastEntryIp,u.memo) from SysUserEntity u ,SysRoleEntity r," +
            "RelUserRoleEntity u_r " +
            "WHERE u.deleteFlag = 0 AND u.activeFlag = 0 AND r.id = u_r.roleId AND u.id = u_r.userId " +
            "AND u.userName = :userName")
    SysUserVo selectSysUserByUserName(@Param("userName") String userName);

    /**
     * 检查系统用户名是否存在
     * @param userName 用户名
     * @return
     */
    @Query(value = "SELECT COUNT(*) FROM sys_user WHERE user_name = :userName", nativeQuery = true)
    int checkUserName(@Param("userName") String userName);

    /**
     * 查找用户实体根据用户名
     * @param userName 用户名
     * @return
     */
    @Query(value = "SELECT * FROM sys_user WHERE user_name = :userName", nativeQuery = true)
    SysUserEntity selectByUserName(@Param("userName") String userName);

    /**
     * 更新用户登录信息
     * @param userName 用户名
     * @param ipAddress ip地址
     * @return
     */
    @Modifying
    @Query(value = "UPDATE sys_user SET last_entry_time = now(), last_entry_ip = :ipAddress " +
            "WHERE user_name = :userName ;", nativeQuery = true)
    int updateSysUserLogin(@Param("userName") String userName,@Param("ipAddress") String ipAddress);

    /**
     * 软删除系统用户根据用户名
     * @param userName 用户名
     * @return
     */
    @Modifying
    @Query(value = "UPDATE sys_user SET delete_flag = 1  " +
            "WHERE user_name = :userName ;", nativeQuery = true)
    int softDeleteSysUserByUserName(@Param("userName") String userName);

    /**
     * 软删除系统用户根据id
     * @param id 编号
     * @return
     */
    @Modifying
    @Query(value = "UPDATE sys_user SET delete_flag = 1  " +
            "WHERE id = :id ;", nativeQuery = true)
    int softDeleteGeneralUserById(@Param("id") Integer id);

    /**
     * 获取所有系统用户Vo（未删除、已激活）
     * @return
     */
    @Query(value = "select new com.xkrs.microservice.model.vo.SysUserVo (u.id, u.userName, u.nickName,u.realName, u.userCode, " +
            "u.sex, u.telephone, u.email, u.admCode, u.address,u.birthday,u.signature,r.roleNameZh, u.portraitId," +
            "u.statusCode,u.addTime,u.lastEntryTime,u.lastEntryIp,u.memo) from SysUserEntity u ,SysRoleEntity r," +
            "RelUserRoleEntity u_r " +
            "WHERE u.deleteFlag = 0 AND u.activeFlag = 0 AND r.id = u_r.roleId AND u.id = u_r.userId")
    List<SysUserVo> selectAllSysUser();

    /**
     * 删除系统用户（危险操作！）
     * @param userName 用户名
     * @return
     */
    @Modifying
    @Query(value = "DELETE FROM sys_user WHERE user_name = :userName ;", nativeQuery = true)
    int deleteSysUser(@Param("userName") String userName);
}
