package com.xkrs.microservice.dao;

import com.xkrs.microservice.model.entity.TifProductEntity;
import org.springframework.data.jpa.repository.JpaRepository;

import java.time.LocalDate;

/**
 * TifProductDao
 * @author tajochen
 */
public interface TifProductDao extends JpaRepository<TifProductEntity,Integer> {

    /**
     * 根据产品代码查找
     * @param productCode 产品代码
     * @return
     */
    TifProductEntity findByProductCode(String productCode);

    /**
     * 根据产品类型查找
     * @param productType 产品类型
     * @return
     */
    Iterable<TifProductEntity> findByProductType(String productType);

    /**
     * 根据产品类型和产品日期查找
     * @param productType 产品类型
     * @param sDate 开始时间
     * @param eDate 结束时间
     * @return
     */
    Iterable<TifProductEntity> findByProductTypeAndProductDateBetween(String productType, LocalDate sDate,LocalDate eDate);

    /**
     * 根据行政区划代码查找
     * @param admCode 行政区划代码
     * @return
     */
    Iterable<TifProductEntity> findByAdmCode(Integer admCode);

    /**
     * 根据行政区划代码和产品日期查找
     * @param admCode 行政区划代码
     * @param sDate 开始时间
     * @param eDate 结束时间
     * @return
     */
    Iterable<TifProductEntity> findByAdmCodeAndProductDateBetween(Integer admCode, LocalDate sDate,LocalDate eDate);

    /**
     * 根据产品类型和行政区划代码和产品类型
     * @param productType 产品类型
     * @param admCode 行政区划代码
     * @return
     */
    Iterable<TifProductEntity> findByProductTypeAndAdmCode(String productType,Integer admCode);

    /**
     * 根据产品类型和行政区划代码和产品类型和产品日期查找
     * @param productType 产品类型
     * @param admCode 行政区划代码
     * @param sDate 开始时间
     * @param eDate 结束时间
     * @return
     */
    Iterable<TifProductEntity> findByProductTypeAndAdmCodeAndProductDateBetween(String productType,Integer admCode, LocalDate sDate,LocalDate eDate);

}
