package com.xkrs.microservice.dao;

import com.xkrs.microservice.model.entity.TypicalPlotIrrigationEntity;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Optional;

/**
 * TypicalPlotIrrigationDao
 * @author tajochen
 */
public interface TypicalPlotIrrigationDao extends JpaRepository<TypicalPlotIrrigationEntity,Integer> {

    /**
     * 查找灌溉记录列表根据地块编号
     * @param dkbh 地块编号
     * @return
     */
    Iterable<TypicalPlotIrrigationEntity> findAllByDkbh(String dkbh);

    /**
     * 查找灌溉记录列表根据区县代码
     * @param countyCode 区县代码
     * @return
     */
    Iterable<TypicalPlotIrrigationEntity> findAllByQxbh(Integer countyCode);

    /**
     * 查找灌溉记录根据灌溉编号
     * @param qxbh 区县代码
     * @param sTime 开始时间
     * @param eTime 结束时间
     * @return
     */
    Iterable<TypicalPlotIrrigationEntity> findAllByQxbhAndEndtimeBetween(Integer qxbh,LocalDateTime sTime,LocalDateTime eTime);

    /**
     * 查找灌溉记录根据灌溉编号
     * @param ggbh 灌溉编号
     * @return
     */
    Optional<TypicalPlotIrrigationEntity> findByGgbh(String ggbh);

    /**
     * 查找灌溉记录根据添加用户名
     * @param addUserName 添加用户名
     * @return
     */
    Iterable<TypicalPlotIrrigationEntity> findAllByAddUserName(String addUserName);

    /**
     * 查找灌溉记录根据区县代码
     * @param xzbh 乡镇编号
     * @param cropCode 作物代码
     * @param startTime 开始时间
     * @param endTime 结束时间
     * @return
     */
    @Query(value = "SELECT * FROM typical_plot_irrigation WHERE CASE WHEN ( :xzbh ) <> '' " +
            "THEN xzbh =  :xzbh ELSE 1 = 1 END " +
            "AND strtime <= :endTime AND endtime >= :startTime " +
            "AND CASE WHEN ( :cropCode ) <> 0 " +
            "THEN crop_code = :cropCode ELSE 1 = 1 END;", nativeQuery = true)
    List<TypicalPlotIrrigationEntity> getAllByCondition(String xzbh, Integer cropCode, LocalDateTime startTime, LocalDateTime endTime);

}
