package com.xkrs.microservice.dao;

import com.xkrs.microservice.model.entity.WcsRecordEntity;
import org.springframework.data.jpa.repository.JpaRepository;

import java.time.LocalDate;

/**
 * WcsRecordDao
 * @author tajochen
 */
public interface WcsRecordDao extends JpaRepository<WcsRecordEntity,Integer> {

    /**
     * 根据服务代码查找
     * @param serviceCode 服务代码
     * @return
     */
    WcsRecordEntity findByServiceCode(String serviceCode);

    /**
     * 根据产品类型查找
     * @param productType 产品类型
     * @return
     */
    Iterable<WcsRecordEntity> findByProductType(String productType);

    /**
     * 根据产品类型和产品日期查找
     * @param productType 产品类型
     * @param sDate 开始时间
     * @param eDate 结束时间
     * @return
     */
    Iterable<WcsRecordEntity> findByProductTypeAndProductDateBetween(String productType, LocalDate sDate, LocalDate eDate);

    /**
     * 根据行政区划代码和产品日期查找
     * @param admCode 行政区划代码
     * @param sDate 开始时间
     * @param eDate 结束时间
     * @return
     */
    Iterable<WcsRecordEntity> findByAdmCodeAndProductDateBetween(Integer admCode, LocalDate sDate, LocalDate eDate);

    /**
     * 根据产品类型和行政区划代码和产品类型
     * @param productType 产品类型
     * @param admCode 行政区划代码
     * @return
     */
    Iterable<WcsRecordEntity> findByProductTypeAndAdmCode(String productType,Integer admCode);

    /**
     * 根据产品类型和行政区划代码和产品类型和产品日期查找
     * @param productType 产品类型
     * @param admCode 行政区划代码
     * @param sDate 开始时间
     * @param eDate 结束时间
     * @return
     */
    Iterable<WcsRecordEntity> findByProductTypeAndAdmCodeAndProductDateBetween(String productType,Integer admCode, LocalDate sDate,LocalDate eDate);

}
