package com.xkrs.microservice.model.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import io.micrometer.core.instrument.util.StringUtils;
import org.locationtech.jts.geom.Geometry;

import javax.persistence.*;
import java.io.Serializable;

/**
 * ShpCounty 表实体类
 * @author tajochen
 */
@Entity
@Table(name="shp_county")
public class ShpCountyEntity implements Serializable {
    /**
     * 指定主键，建立自增序列，主键值取自序列
     */
    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "shp_county_seq_gen")
    @SequenceGenerator(name = "shp_county_seq_gen", sequenceName = "shp_county_seq",allocationSize = 1)
    private Integer id;

    @Column( nullable = false, unique = true, columnDefinition = "int4")
    private Integer code;

    @Column(length = 32, nullable = false, columnDefinition = "varchar(32)")
    private String name;

    @Column( nullable = false, columnDefinition = "int4")
    private Integer cityCode;

    @Column(length = 32, nullable = false, columnDefinition = "varchar(32)")
    private String cityName;

    @Column( nullable = false, columnDefinition = "int4")
    private Integer proCode;

    @Column(length = 16, nullable = false, columnDefinition = "varchar(16)")
    private String proName;

    private double shapeArea;

    @Column( columnDefinition = "varchar(192)")
    private String center;

    @Column( columnDefinition = "varchar(192)")
    private String memo;

    private Geometry geom;

    @Transient
    private String wktGeom;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getCode() {
        return code;
    }

    public void setCode(Integer code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getCityCode() {
        return cityCode;
    }

    public void setCityCode(Integer cityCode) {
        this.cityCode = cityCode;
    }

    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }

    public Integer getProCode() {
        return proCode;
    }

    public void setProCode(Integer proCode) {
        this.proCode = proCode;
    }

    public String getProName() {
        return proName;
    }

    public void setProName(String proName) {
        this.proName = proName;
    }

    public double getShapeArea() {
        return shapeArea;
    }

    public void setShapeArea(double shapeArea) {
        this.shapeArea = shapeArea;
    }

    public String getCenter() {
        return center;
    }

    public void setCenter(String center) {
        this.center = center;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    @JsonIgnore
    public Geometry getGeom() {
        return geom;
    }

    @JsonIgnore
    public void setGeom(Geometry geom) {
        this.geom = geom;
    }

    public String getWktGeom() {
        if(StringUtils.isNotBlank(wktGeom)){
            return wktGeom;
        } else if(geom == null){
            return "";
        } else {
            return geom.toString();
        }
    }

    public void setWktGeom(String wktGeom) {
        this.wktGeom = wktGeom;
    }

    @Override
    public String toString() {
        return "ShpCountyEntity{" +
                "id=" + id +
                ", code=" + code +
                ", name='" + name + '\'' +
                ", cityCode=" + cityCode +
                ", cityName='" + cityName + '\'' +
                ", proCode=" + proCode +
                ", proName='" + proName + '\'' +
                ", shapeArea=" + shapeArea +
                ", center='" + center + '\'' +
                ", memo='" + memo + '\'' +
                ", geom=" + geom +
                ", wktGeom='" + wktGeom + '\'' +
                '}';
    }
}
