package com.xkrs.microservice.model.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import io.micrometer.core.instrument.util.StringUtils;
import org.geolatte.geom.Geometry;

import javax.persistence.*;
import java.io.Serializable;

/**
 * ShpProvince 表实体类
 * @author tajochen
 */
@Entity
@Table(name="shp_province")
public class ShpProvinceEntity implements Serializable {
    /**
     * 指定主键，建立自增序列，主键值取自序列
     */
    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "shp_province_seq_gen")
    @SequenceGenerator(name = "shp_province_seq_gen", sequenceName = "shp_province_seq",allocationSize = 1)
    private Integer id;

    @Column( nullable = false, unique = true, columnDefinition = "int4")
    private Integer code;

    @Column(length = 16, nullable = false, columnDefinition = "varchar(16)")
    private String name;

    private double shapeArea;

    @Column( columnDefinition = "varchar(192)")
    private String center;

    private Geometry geom;

    @Transient
    private String wktGeom;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getCode() {
        return code;
    }

    public void setCode(Integer code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public double getShapeArea() {
        return shapeArea;
    }

    public void setShapeArea(double shapeArea) {
        this.shapeArea = shapeArea;
    }

    public String getCenter() {
        return center;
    }

    public void setCenter(String center) {
        this.center = center;
    }

    @JsonIgnore
    public Geometry getGeom() {
        return geom;
    }

    @JsonIgnore
    public void setGeom(Geometry geom) {
        this.geom = geom;
    }

    public String getWktGeom() {
        if(StringUtils.isNotBlank(wktGeom)){
            return wktGeom;
        } else if(geom == null){
            return "";
        } else {
            return geom.toString();
        }
    }

    public void setWktGeom(String wktGeom) {
        this.wktGeom = wktGeom;
    }

    @Override
    public String toString() {
        return "ShpProvinceEntity{" +
                "id=" + id +
                ", code=" + code +
                ", name='" + name + '\'' +
                ", shapeArea=" + shapeArea +
                ", center='" + center + '\'' +
                ", geom=" + geom +
                ", wktGeom='" + wktGeom + '\'' +
                '}';
    }
}

