package com.xkrs.microservice.model.qo;

import com.xkrs.microservice.model.validation.AppFileQoInsert;
import com.xkrs.microservice.model.validation.AppFileQoUpdate;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;

/**
 * AppFileQo
 * @author tajochen
 */
public class AppFileQo {

    @NotNull(message = "{AppFile.id.null}",groups={AppFileQoUpdate.class})
    private Integer id;

    @NotBlank(message = "{AppFile.name.null}",groups = {AppFileQoInsert.class, AppFileQoUpdate.class})
    @Size(max = 64, message = "{AppFile.name.length.illegal}",groups = {AppFileQoInsert.class, AppFileQoUpdate.class})
    private String name;

    @NotBlank(message = "{AppFile.appPath.null}",groups = {AppFileQoInsert.class, AppFileQoUpdate.class})
    @Size(max = 192, message = "{AppFile.appPath.length.illegal}",groups = {AppFileQoInsert.class, AppFileQoUpdate.class})
    private String appPath;

    @NotBlank(message = "{AppFile.versionNumber.null}",groups = {AppFileQoInsert.class, AppFileQoUpdate.class})
    @Size(max = 128, message = "{AppFile.versionNumber.length.illegal}",groups = {AppFileQoInsert.class, AppFileQoUpdate.class})
    @Pattern(regexp = "^([1-9]\\d|[1-9])(.([1-9]\\d|\\d)){2}$",message = "{AppFile.versionNumber.format.illegal}",groups = {AppFileQoInsert.class,
            AppFileQoUpdate.class})
    private String versionNumber;

    @NotBlank(message = "{AppFile.size.null}",groups = {AppFileQoInsert.class, AppFileQoUpdate.class})
    @Size(max = 128, message = "{AppFile.size.length.illegal}",groups = {AppFileQoInsert.class, AppFileQoUpdate.class})
    private String size;

    @NotBlank(message = "{AppFile.md5.null}",groups = {AppFileQoInsert.class, AppFileQoUpdate.class})
    @Size(max = 192, message = "{AppFile.md5.length.illegal}",groups = {AppFileQoInsert.class, AppFileQoUpdate.class})
    private String md5;

    @Size(max = 128, message = "{AppFile.memo.length.illegal}",groups = {AppFileQoInsert.class, AppFileQoUpdate.class})
    private String memo;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAppPath() {
        return appPath;
    }

    public void setAppPath(String appPath) {
        this.appPath = appPath;
    }

    public String getVersionNumber() {
        return versionNumber;
    }

    public void setVersionNumber(String versionNumber) {
        this.versionNumber = versionNumber;
    }

    public String getSize() {
        return size;
    }

    public void setSize(String size) {
        this.size = size;
    }

    public String getMd5() {
        return md5;
    }

    public void setMd5(String md5) {
        this.md5 = md5;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
}
