package com.xkrs.microservice.model.qo;

import com.xkrs.microservice.model.validation.SysUserQoInsert;
import com.xkrs.microservice.model.validation.SysUserQoUpdate;
import org.hibernate.validator.constraints.Range;

import javax.validation.constraints.*;

/**
 * SysUserQo
 * @author tajochen
 */
public class SysUserQo {

    @NotNull( message = "{SysUser.id.blank}",groups={SysUserQoUpdate.class})
    private Integer id;

    @NotBlank(message = "{SysUser.userName.blank}",groups={SysUserQoInsert.class})
    @Size(min = 3,max = 24, message = "{SysUser.userName.length.illegal}",groups = {SysUserQoInsert.class,
            SysUserQoUpdate.class})
    @Pattern(regexp = "^([A-Za-z0-9_]+)$",message = "{SysUser.userName.format.illegal}",groups = {SysUserQoInsert.class,
            SysUserQoUpdate.class})
    private String userName;

    @Size(min = 2,max = 24, message = "{SysUser.nickName.length.illegal}",groups = {SysUserQoInsert.class,
            SysUserQoUpdate.class})
    private String nickName;

    @Size(min = 2,max = 24, message = "{SysUser.realName.length.illegal}",groups = {SysUserQoInsert.class,
            SysUserQoUpdate.class})
    private String realName;

    @Size(max = 128, message = "{SysUser.memo.length.illegal}",groups = {SysUserQoInsert.class,
            SysUserQoUpdate.class})
    private String memo;

    @Size(min = 0,max = 16, message = "{SysUser.userCode.length.illegal}",groups = {SysUserQoInsert.class,
            SysUserQoUpdate.class})
    @Pattern(regexp = "/^[A-Za-z0-9_-]{3,16}$/g",message = "{SysUser.userCode.format.illegal}",
            groups = {SysUserQoInsert.class, SysUserQoUpdate.class})
    private String userCode;

    @NotBlank(message = "{SysUser.password.blank}",groups = {SysUserQoInsert.class})
    @Size(min = 6,max = 16, message = "{SysUser.password.length.illegal}",groups = {SysUserQoInsert.class,
            SysUserQoUpdate.class})
    @Pattern(regexp = "^(?![0-9]+$)(?![a-zA-Z]+$)[0-9A-Za-z]{6,16}$",message = "{SysUser.password.format.illegal}",
            groups = {SysUserQoInsert.class,SysUserQoUpdate.class})
    private String password;

    @Range(min=0,max=2,message = "{SysUser.sex.num.illegal}",groups = {SysUserQoInsert.class, SysUserQoUpdate.class})
    private Integer sex;

    @Pattern(regexp = "^(13[0-9]|14[0-9]|15[0-9]|16[0-9]|17[0-9]|18[0-9]|19[0-9])\\d{8}$",
            message = "{SysUser.telephone.format.illegal}",groups = {SysUserQoInsert.class,SysUserQoUpdate.class})
    private String telephone;

    @Size(max = 32, message = "{SysUser.email.length.illegal}",groups = {SysUserQoInsert.class, SysUserQoUpdate.class})
    @Email(message = "{SysUser.email.format.illegal}",groups = {SysUserQoInsert.class, SysUserQoUpdate.class})
    private String email;

    private Integer admCode;

    @Size(max = 64, message = "{SysUser.address.length.illegal}",groups = {SysUserQoInsert.class, SysUserQoUpdate.class})
    private String address;

    private Long birthdayTs;

    @Size(max = 128, message = "{SysUser.personalSignature.length.illegal}",groups = {SysUserQoInsert.class,
            SysUserQoUpdate.class})
    private String signature;

    @NotNull(message = "{SysUser.portraitId.illegal}",groups = { SysUserQoUpdate.class})
    private Integer portraitId;

    @NotNull(message = "{SysUser.statusCode.illegal}",groups={SysUserQoUpdate.class})
    @Range(min=0,max=2,message = "{SysUser.statusCode.illegal}",groups = {SysUserQoInsert.class, SysUserQoUpdate.class})
    private Integer statusCode;

    @NotNull(message = "{SysUser.deleteFlag.null}",groups={SysUserQoUpdate.class})
    private Integer deleteFlag;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }

    public String getTelephone() {
        return telephone;
    }

    public void setTelephone(String telephone) {
        this.telephone = telephone;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Integer getAdmCode() {
        return admCode;
    }

    public void setAdmCode(Integer admCode) {
        this.admCode = admCode;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public Long getBirthdayTs() {
        return birthdayTs;
    }

    public void setBirthdayTs(Long birthdayTs) {
        this.birthdayTs = birthdayTs;
    }

    public String getSignature() {
        return signature;
    }

    public void setSignature(String signature) {
        this.signature = signature;
    }

    public Integer getPortraitId() {
        return portraitId;
    }

    public void setPortraitId(Integer portraitId) {
        this.portraitId = portraitId;
    }

    public Integer getStatusCode() {
        return statusCode;
    }

    public void setStatusCode(Integer statusCode) {
        this.statusCode = statusCode;
    }

    public Integer getDeleteFlag() {
        return deleteFlag;
    }

    public void setDeleteFlag(Integer deleteFlag) {
        this.deleteFlag = deleteFlag;
    }

    public String getRealName() {
        return realName;
    }

    public void setRealName(String realName) {
        this.realName = realName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
}
