package com.xkrs.microservice.model.qo;

import com.xkrs.microservice.model.validation.SysUserQoInsert;
import com.xkrs.microservice.model.validation.SysUserQoUpdate;
import com.xkrs.microservice.model.validation.TypicalFarmerQoInsert;
import com.xkrs.microservice.model.validation.TypicalFarmerQoUpdate;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;

/**
 * TypicalFarmerQo
 * @author tajochen
 */
public class TypicalFarmerQo {

    @NotBlank(message = "{TypicalFarmer.lxr.null}",groups = {TypicalFarmerQoInsert.class, TypicalFarmerQoUpdate.class})
    @Size(max = 16, message = "{TypicalFarmer.lxr.length.illegal}",groups = {TypicalFarmerQoInsert.class, TypicalFarmerQoUpdate.class})
    private String lxr;

    @Size(max = 32, message = "{TypicalFarmer.lxrid.length.illegal}",groups = {TypicalFarmerQoInsert.class, TypicalFarmerQoUpdate.class})
    private String lxrid;

    @NotBlank(message = "{TypicalFarmer.tel.null}",groups = {TypicalFarmerQoInsert.class, TypicalFarmerQoUpdate.class})
    @Pattern(regexp = "^(13[0-9]|14[0-9]|15[0-9]|16[0-9]|17[0-9]|18[0-9]|19[0-9])\\d{8}$",
            message = "{SysUser.telephone.format.illegal}",groups = {SysUserQoInsert.class, SysUserQoUpdate.class})
    private String tel;

    private Integer qxdm;

    @Size(max = 32, message = "{TypicalFarmer.qxmc.length.illegal}",groups = {TypicalFarmerQoInsert.class})
    private String qxmc;

    @Size(max = 32, message = "{TypicalFarmer.xzdm.length.illegal}",groups = {TypicalFarmerQoInsert.class})
    private String xzdm;

    @Size(max = 32, message = "{TypicalFarmer.xzmc.length.illegal}",groups = {TypicalFarmerQoInsert.class})
    private String xzmc;

    @Size(max = 64, message = "{TypicalFarmer.address.length.illegal}",groups = {TypicalFarmerQoInsert.class, TypicalFarmerQoUpdate.class})
    private String address;

    private Long strdateTs;

    private Long enddateTs;

    @Size(max = 512, message = "{TypicalFarmer.xyzp.length.illegal}",groups = {TypicalFarmerQoInsert.class, TypicalFarmerQoUpdate.class})
    private String xyzp;

    @Size(max = 64, message = "{TypicalFarmer.remark.length.illegal}",groups = {TypicalFarmerQoInsert.class, TypicalFarmerQoUpdate.class})
    private String remark;

    @NotBlank(message = "{TypicalFarmer.password.blank}",groups = {SysUserQoInsert.class})
    @Size(min = 6,max = 16, message = "{TypicalFarmer.password.length.illegal}",groups = {SysUserQoInsert.class})
    @Pattern(regexp = "^(?![0-9]+$)(?![a-zA-Z]+$)[0-9A-Za-z]{6,16}$",message = "{TypicalFarmer.password.format.illegal}",
            groups = {SysUserQoInsert.class})
    private String password;

    public String getLxr() {
        return lxr;
    }

    public void setLxr(String lxr) {
        this.lxr = lxr;
    }

    public String getLxrid() {
        return lxrid;
    }

    public void setLxrid(String lxrid) {
        this.lxrid = lxrid;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }

    public Integer getQxdm() {
        return qxdm;
    }

    public void setQxdm(Integer qxdm) {
        this.qxdm = qxdm;
    }

    public String getQxmc() {
        return qxmc;
    }

    public void setQxmc(String qxmc) {
        this.qxmc = qxmc;
    }

    public String getXzdm() {
        return xzdm;
    }

    public void setXzdm(String xzdm) {
        this.xzdm = xzdm;
    }

    public String getXzmc() {
        return xzmc;
    }

    public void setXzmc(String xzmc) {
        this.xzmc = xzmc;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public Long getStrdateTs() {
        return strdateTs;
    }

    public void setStrdateTs(Long strdateTs) {
        this.strdateTs = strdateTs;
    }

    public Long getEnddateTs() {
        return enddateTs;
    }

    public void setEnddateTs(Long enddateTs) {
        this.enddateTs = enddateTs;
    }

    public String getXyzp() {
        return xyzp;
    }

    public void setXyzp(String xyzp) {
        this.xyzp = xyzp;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }
}
