package com.xkrs.microservice.service;

import com.xkrs.microservice.model.entity.FileAppEntity;
import com.xkrs.microservice.model.qo.AppFileQo;

import java.util.List;
import java.util.Optional;

/**
 * App管理接口
 * @author tajochen
 */
public interface AppManageService {

    /**
     * 获取所有APP版本列表
     * @return
     */
    Iterable<FileAppEntity> getAllFile();

    /**
     * 获取指定id记录
     * @param id 编号
     * @return
     */
    Optional<FileAppEntity> getById(Integer id);

    /**
     * 获取指定版本号的记录
     * @param versionNumber 版本号
     * @return
     */
    Iterable<FileAppEntity> getByVersionNumber(String versionNumber);

    /**
     * 检查App的版本号
     * @param versionNumber 版本号
     * @return
     */
    List<FileAppEntity> checkLastVersionNumber(String versionNumber);

    /**
     * 新增APP记录
     * @param appFileQo app属性
     * @param userName 用户名
     */
    void add(AppFileQo appFileQo, String userName);

    /**
     * 删除APP记录
     * @param id 编号
     */
    void delete(Integer id);

}
