package com.xkrs.microservice.service;

import com.xkrs.microservice.model.entity.CropClassifyRecordEntity;
import com.xkrs.microservice.model.qo.CropClassifyRecordQo;

import java.time.LocalDate;
import java.util.Optional;

/**
 * 种植分类记录数据服务管理接口
 * @author tajochen
 */
public interface CropClassifyRecordService {

    /**
     * 获取所有种植分类记录
     * @return
     */
    Iterable<CropClassifyRecordEntity> getAllRecord();

    /**
     * 获取指定id的种植分类记录
     * @param id 记录编号
     * @return
     */
    Optional<CropClassifyRecordEntity> getById(Integer id);

    /**
     * 获取指定行政区划的所有种植分类记录
     * @param admCode 行政区划代码
     * @return
     */
    Iterable<CropClassifyRecordEntity> getByAdmCode(Integer admCode);

    /**
     * 获取指定街道和日期的所有种植分类记录
     * @param townCode 街道代码
     * @param startDate 开始日期
     * @param endDate 结束日期
     * @return
     */
    Iterable<CropClassifyRecordEntity> getByTownCodeAndDate(String townCode, LocalDate startDate, LocalDate endDate);

    /**
     * 获取指定行政区划和时间段的所有种植分类核查记录
     * @param admCode 行政区划代码
     * @param startDate 开始时间
     * @param endDate 结束时间
     * @return
     */
    Iterable<CropClassifyRecordEntity> getByAdmCodeAndDateTime(Integer admCode, LocalDate startDate, LocalDate endDate);

    /**
     * 新增种植分类记录
     * @param cropClassifyRecordQo
     * @param userName 用户名
     */
    void add(CropClassifyRecordQo cropClassifyRecordQo, String userName);

    /**
     * 删除种植分类记录
     * @param id
     */
    void delete(Integer id);

}
