package com.xkrs.microservice.service;

import com.xkrs.microservice.model.entity.FarmingInfoEntity;
import com.xkrs.microservice.model.qo.FarmingInfoQo;

import java.util.Optional;

/**
 * 农情信息服务管理接口
 * @author tajochen
 */
public interface FarmingInfoService {

    /**
     * 获取所有农情信息
     * @return
     */
    Iterable<FarmingInfoEntity> getAllRecord();

    /**
     * 获取指定id的农情信息
     * @param id 记录编号
     * @return
     */
    Optional<FarmingInfoEntity> getById(Integer id);

    /**
     * 查找农情信息根据地块编号
     * @param dkbh 地块编码
     * @return
     */
    Iterable<FarmingInfoEntity> getByDkbh(String dkbh);

    /**
     * 查找农情信息根据区县编号
     * @param qxbh 区县编号
     * @return
     */
    Iterable<FarmingInfoEntity> getByQxbh(Integer qxbh);

    /**
     * 查找农情信息根据作物代码，区县编号
     * @param qxbh 区县编号
     * @param zwbh 作物代码
     * @return
     */
    Iterable<FarmingInfoEntity> getByZwdmAndQxbh(Integer zwbh,Integer qxbh);

    /**
     * 获取所有新农情根据区县编号
     * @param qxbh
     * @return
     */
    Iterable<FarmingInfoEntity> getNewByQxbh(Integer qxbh);

    /**
     * 获取所有农情信息根据用户名
     * @param userName 用户名
     * @return
     */
    Iterable<FarmingInfoEntity> getByUserName(String userName);

    /**
     * 新增农情信息
     * @param farmingInfoQo
     * @param userName 用户名
     */
    void add(FarmingInfoQo farmingInfoQo, String userName);

    /**
     * 删除农情信息
     * @param id
     */
    void delete(Integer id);

}
