package com.xkrs.microservice.service;

import com.xkrs.microservice.model.entity.IrrigationCheckEntity;
import com.xkrs.microservice.model.qo.IrrigationCheckQo;

import java.time.LocalDateTime;
import java.util.Optional;

/**
 * 灌溉核查记录服务管理接口
 * @author tajochen
 */
public interface IrrigationCheckService {

    /**
     * 获取所有灌溉核查记录
     * @return
     */
    Iterable<IrrigationCheckEntity> getAllRecord();

    /**
     * 获取指定id的灌溉核查记录
     * @param id 记录编号
     * @return
     */
    Optional<IrrigationCheckEntity> getById(Integer id);

    /**
     * 获取指定用户的所有灌溉核查记录
     * @param userName 用户名
     * @return
     */
    Iterable<IrrigationCheckEntity> getByUserName(String userName);

    /**
     * 获取指定地块编号的所有灌溉核查记录
     * @param dkbh 地块编号
     * @return
     */
    Iterable<IrrigationCheckEntity> getByDkbh(String dkbh);

    /**
     * 获取指定地块编号的所有区县编号
     * @param qxbh 区县编号
     * @return
     */
    Iterable<IrrigationCheckEntity> getByQxbh(Integer qxbh);

    /**
     * 查找灌溉核查结果根据区县编号和时间
     * @param qxbh 区县编号
     * @param sTime 开始时间
     * @param eTime 结束时间
     * @return
     */
    Iterable<IrrigationCheckEntity> getByQxbhAndCreateTimeBetween(Integer qxbh, LocalDateTime sTime, LocalDateTime eTime);

    /**
     * 获取指定灌溉编号的所有灌溉核查记录
     * @param ggbh 灌溉编号
     * @return
     */
    Optional<IrrigationCheckEntity> getByGgbh(String ggbh);

    /**
     * 新增灌溉核查记录
     * @param irrigationCheckQo
     * @param userName 用户名
     */
    void add(IrrigationCheckQo irrigationCheckQo, String userName);

    /**
     * 删除灌溉核查记录
     * @param id
     */
    void delete(Integer id);

}
