package com.xkrs.microservice.service;

import com.xkrs.microservice.model.entity.IrrigationRecordEntity;
import com.xkrs.microservice.model.qo.IrrigationRecordQo;

import java.time.LocalDate;
import java.util.Optional;

/**
 * 灌溉记录数据服务管理接口
 * @author tajochen
 */
public interface IrrigationRecordService {

    /**
     * 获取所有灌溉记录
     * @return
     */
    Iterable<IrrigationRecordEntity> getAllRecord();

    /**
     * 获取指定id的记录
     * @param id 记录编号
     * @return
     */
    Optional<IrrigationRecordEntity> getById(Integer id);

    /**
     * 获取指定行政区划的所有灌溉记录
     * @param admCode 行政区划代码
     * @return
     */
    Iterable<IrrigationRecordEntity> getByAdmCode(Integer admCode);

    /**
     * 获取指定街道代码和时间段的所有灌溉记录
     * @param townCode 行政区划代码
     * @param startDate 开始时间
     * @param endDate 结束时间
     * @return
     */
    Iterable<IrrigationRecordEntity> getByTownCodeAndDate(String townCode, LocalDate startDate, LocalDate endDate);

    /**
     * 获取指定行政区划和时间段的所有灌溉核查记录
     * @param admCode 行政区划代码
     * @param startDate 开始时间
     * @param endDate 结束时间
     * @return
     */
    Iterable<IrrigationRecordEntity> getByAdmCodeAndDateTime(Integer admCode, LocalDate startDate, LocalDate endDate);

    /**
     * 新增灌溉记录
     * @param irrigationFieldCheckQo
     * @param userName 用户名
     */
    void add(IrrigationRecordQo irrigationFieldCheckQo, String userName);

    /**
     * 删除灌溉记录
     * @param id
     */
    void delete(Integer id);

}
