package com.xkrs.microservice.service;

import com.xkrs.microservice.model.entity.IrrigationSarRecordEntity;
import com.xkrs.microservice.model.qo.IrrigationSarRecordQo;

import java.time.LocalDate;
import java.util.Optional;

/**
 * 灌溉Sar记录数据服务管理接口
 * @author tajochen
 */
public interface IrrigationSarRecordService {

    /**
     * 获取所有灌溉记录
     * @return
     */
    Iterable<IrrigationSarRecordEntity> getAllRecord();

    /**
     * 获取指定id的记录
     * @param id 记录编号
     * @return
     */
    Optional<IrrigationSarRecordEntity> getById(Integer id);

    /**
     * 获取指定行政区划的所有灌溉记录
     * @param admCode 行政区划代码
     * @return
     */
    Iterable<IrrigationSarRecordEntity> getByAdmCode(Integer admCode);

    /**
     * 获取指定街道代码和时间段的所有灌溉记录
     * @param townCode 行政区划代码
     * @param startDate 开始时间
     * @param endDate 结束时间
     * @return
     */
    Iterable<IrrigationSarRecordEntity> getByTownCodeAndDate(String townCode, LocalDate startDate, LocalDate endDate);

    /**
     * 获取灌溉统计动态多条件查询
     * @param townCode 行政区划代码
     * @param startDate 开始时间
     * @param endDate 结束时间
     * @return
     */
    Iterable<IrrigationSarRecordEntity> geAllByCondition(String townCode, LocalDate startDate, LocalDate endDate);

    /**
     * 获取指定行政区划和时间段的所有灌溉核查记录
     * @param admCode 行政区划代码
     * @param startDate 开始时间
     * @param endDate 结束时间
     * @return
     */
    Iterable<IrrigationSarRecordEntity> getByAdmCodeAndDateTime(Integer admCode, LocalDate startDate, LocalDate endDate);

    /**
     * 新增灌溉记录
     * @param irrigationSarRecordQo
     * @param userName 用户名
     */
    void add(IrrigationSarRecordQo irrigationSarRecordQo, String userName);

    /**
     * 删除灌溉记录
     * @param id
     */
    void delete(Integer id);

}
