package com.xkrs.microservice.service;

import com.xkrs.microservice.model.entity.SysUserEntity;
import com.xkrs.microservice.model.qo.SysUserQo;
import com.xkrs.microservice.model.vo.SysUserVo;

/**
 * 系统用户服务接口
 * @author tajochen
 */
public interface SysUserService {

    /**
     * 获取指定用户Vo
     * @param userName 用户名
     * @return
     */
    SysUserVo getSysUserVoByUserName(String userName);

    /**
     * 用户头像更新
     * @param userName 用户名
     * @param portraitId 编号
     * @return
     */
    int updateSysUserPortrait(String userName,Integer portraitId);

    /**
     * 用户密码更新
     * @param userName 用户名
     * @param oldPassword 旧密码
     * @param newPassword 新密码
     * @return
     */
    int updateSysUserPassword(String userName,String oldPassword,String newPassword);

    /**
     * 检查用户名
     * @param userName 用户名
     * @return
     */
    boolean checkUserName(String userName);

    /**
     * 获取所有用户
     * @return
     */
    Iterable<SysUserVo> getAllSysUser();

    /**
     * 保存用户
     * @param sysUserQo
     */
    void addUser(SysUserQo sysUserQo);

    /**
     * 获取系统用户实体根据用户名
     * @param userName 用户名
     * @return
     */
    SysUserEntity getSysUserByUserName(String userName);

    /**
     * 用户登录更新
     * @param userName 用户名
     * @param ipAddress ip地址
     * @return
     */
    int updateSysUserLogin(String userName,String ipAddress);

    /**
     * 系统用户更新
     * @param sysUserQo
     * @return
     */
    int updateSysUser(SysUserQo sysUserQo);

    /**
     * 禁用用户账号
     * @param userName
     * @return
     */
    int disableSysUser(String userName);

    /**
     * 启用用户账号
     * @param userName
     * @return
     */
    int enableSysUser(String userName);

    /**
     * 软删除系统用户
     * @param id 编号
     * @return
     */
    int softDeleteGeneralUser(Integer id);
}
