package com.xkrs.microservice.service;

import com.xkrs.microservice.model.entity.TifProductEntity;
import com.xkrs.microservice.model.qo.TifProductQo;
import org.springframework.cache.annotation.Cacheable;

import javax.persistence.criteria.CriteriaBuilder;
import java.time.LocalDate;
import java.util.Optional;

/**
 * 栅格产品管理接口
 * @author tajochen
 */
public interface TifProductService {

    /**
     * 获取所有栅格产品
     * @return
     */
    Iterable<TifProductEntity> getAllFile();

    /**
     * 获取指定产品编号的产品
     * @param productCode 产品编号
     * @return
     */
    TifProductEntity getByProductCode(String productCode);

    /**
     * 获取指定id的产品
     * @param id 产品编号
     * @return
     */
    Optional<TifProductEntity> getById(Integer id);

    /**
     * 获取指定类型的所有产品
     * @param productType 产品类型
     * @return
     */
    Iterable<TifProductEntity> getByProductType(String productType);

    /**
     * 获取指定类型和时间段的所有产品
     * @param productType 产品类型
     * @param startDate 开始日期
     * @param endDate 结束日期
     * @return
     */
    Iterable<TifProductEntity> getByProductTypeAndDate(String productType, LocalDate startDate,LocalDate endDate);

    /**
     * 获取指定类型和行政区划的所有产品
     * @param admCode 行政区划
     * @param productType 产品类型
     * @return
     */
    Iterable<TifProductEntity> getByAdmCodeAndProductType(Integer admCode,String productType);

    /**
     * 获取指定行政区划和时间段的所有产品
     * @param admCode 行政区划代码
     * @param startDate 开始日期
     * @param endDate 结束日期
     * @return
     */
    Iterable<TifProductEntity> getByAdmCodeAndProductDateBetween(Integer admCode, LocalDate startDate,LocalDate endDate);

    /**
     * 获取指定类型和行政区划和时间段的所有产品
     * @param admCode 行政区划
     * @param productType 产品类型
     * @param startDate 开始日期
     * @param endDate 结束日期
     * @return
     */
    Iterable<TifProductEntity> getByAdmCodeAndProductTypeAndDate(Integer admCode,String productType, LocalDate startDate,LocalDate endDate);

    /**
     * 新增栅格产品
     * @param tifProductQo
     * @param userName 用户名
     */
    void add(TifProductQo tifProductQo, String userName);

    /**
     * 删除栅格产品
     * @param id
     */
    void delete(Integer id);

}
