package com.xkrs.microservice.service;

import com.xkrs.microservice.model.entity.TypicalFarmerEntity;
import com.xkrs.microservice.model.qo.TypicalFarmerQo;

import java.util.Optional;

/**
 * 典型区农户服务管理接口
 * @author tajochen
 */
public interface TypicalFarmerService {

    /**
     * 获取所有农户记录
     * @return
     */
    Iterable<TypicalFarmerEntity> getAllRecord();

    /**
     * 获取指定id的农户记录
     * @param id 记录编号
     * @return
     */
    Optional<TypicalFarmerEntity> getById(Integer id);

    /**
     * 获取指定乡镇代码的所有农户记录
     * @param xzdm 乡镇代码
     * @return
     */
    Iterable<TypicalFarmerEntity> getByTownCode(String xzdm);

    /**
     * 获取指定区县代码的所有农户记录
     * @param qxdm 区县代码
     * @return
     */
    Iterable<TypicalFarmerEntity> getByCountyCode(Integer qxdm);

    /**
     * 获取指定姓名的农户记录
     * @param lxr 联系人
     * @return
     */
    Iterable<TypicalFarmerEntity> getByLxr(String lxr);

    /**
     * 获取指定手机号的所有农户记录
     * @param tel 手机号
     * @return
     */
    Optional<TypicalFarmerEntity> getByTel(String tel);

    /**
     * 新增农户记录
     * @param typicalFarmerQo
     * @param userName 用户名
     */
    void add(TypicalFarmerQo typicalFarmerQo, String userName);

    /**
     * 修改农户记录
     * @param typicalFarmerQo
     */
    void update(TypicalFarmerQo typicalFarmerQo);

    /**
     * 删除农户记录
     * @param id
     */
    void delete(Integer id);

}
