package com.xkrs.microservice.service;

import com.xkrs.microservice.model.entity.TypicalPlotIrrigationEntity;
import com.xkrs.microservice.model.qo.TypicalPlotIrrigationQo;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Optional;

/**
 * 典型区地块灌溉信息管理接口
 * @author tajochen
 */
public interface TypicalPlotIrrigationService {

    /**
     * 获取所有地块灌溉信息
     * @return
     */
    Iterable<TypicalPlotIrrigationEntity> getAllRecord();

    /**
     * 获取指定id的地块灌溉信息
     * @param id 记录编号
     * @return
     */
    Optional<TypicalPlotIrrigationEntity> getById(Integer id);

    /**
     * 获取指定灌溉编号的某个地块灌溉信息
     * @param ggbh 灌溉编号
     * @return
     */
    Optional<TypicalPlotIrrigationEntity> getByGgbh(String ggbh);

    /**
     * 查找灌溉记录列表根据区县编号
     * @param qxbh 区县编号
     * @return
     */
    Iterable<TypicalPlotIrrigationEntity> getByQxbh(Integer qxbh);

    /**
     * 查找灌溉记录列表根据地块编号
     * @param dkbh 地块编号
     * @return
     */
    Iterable<TypicalPlotIrrigationEntity> getByDkbh(String dkbh);

    /**
     * 查找灌溉记录根据灌溉编号
     * @param qxbh 区县代码
     * @param sTime 开始时间
     * @param eTime 结束时间
     * @return
     */
    Iterable<TypicalPlotIrrigationEntity> findAllByQxbhAndStrtimeBetween(Integer qxbh, LocalDateTime sTime, LocalDateTime eTime);

    /**
     * 查找灌溉记录根据动态多条件
     * @param xzbh 乡镇街道代码
     * @param cropCode 作物代码
     * @param sTime 开始时间
     * @param eTime 结束时间
     * @return
     */
    List<TypicalPlotIrrigationEntity> getAllByCondition(String xzbh,Integer cropCode, Long sTime, Long eTime);

    /**
     * 获取指定用户名的所有地块灌溉信息
     * @param userName 用户名
     * @return
     */
    Iterable<TypicalPlotIrrigationEntity> getByUserName(String userName);

    /**
     * 新增地块灌溉信息
     * @param typicalPlotIrrigationQo
     * @param userName 用户名
     */
    void add(TypicalPlotIrrigationQo typicalPlotIrrigationQo, String userName);

    /**
     * 删除地块灌溉信息
     * @param id
     */
    void delete(Integer id);

}
