package com.xkrs.microservice.service;

import com.xkrs.microservice.model.entity.TypicalPlotEntity;
import com.xkrs.microservice.model.qo.TypicalPlotQo;

import java.util.Optional;

/**
 * 典型地块服务管理接口
 * @author tajochen
 */
public interface TypicalPlotService {

    /**
     * 获取所有典型地块记录
     * @return
     */
    Iterable<TypicalPlotEntity> getAllRecord();

    /**
     * 获取指定id的典型地块记录
     * @param id 记录编号
     * @return
     */
    Optional<TypicalPlotEntity> getById(Integer id);

    /**
     * 获取指定编号的典型地块记录
     * @param dkbh 地块编号
     * @return
     */
    Optional<TypicalPlotEntity> getByDkbh(String dkbh);

    /**
     * 获取指定区县代码的所有典型地块记录
     * @param qxdm 区县代码
     * @return
     */
    Iterable<TypicalPlotEntity> getByCountyCode(Integer qxdm);

    /**
     * 获取指定乡镇街道代码的所有典型地块记录
     * @param xzdm 街道代码
     * @return
     */
    Iterable<TypicalPlotEntity> getByTownCode(String xzdm);

    /**
     * 获取指定联系人的所有典型地块记录
     * @param lxr 联系人
     * @return
     */
    Iterable<TypicalPlotEntity> getByLxr(String lxr);

    /**
     * 获取指定手机号的所有典型地块记录
     * @param tel 手机号
     * @return
     */
    Iterable<TypicalPlotEntity> getByTel(String tel);

    /**
     * 新增典型地块记录
     * @param typicalPlotQo
     * @param userName 用户名
     */
    void add(TypicalPlotQo typicalPlotQo,String userName);

    /**
     * 更新典型地块记录
     * @param typicalPlotQo
     * @param userName
     */
    void update(TypicalPlotQo typicalPlotQo,String userName);

    /**
     * 删除典型地块记录
     * @param id
     */
    void delete(Integer id);

}
