package com.xkrs.microservice.service;

import com.xkrs.microservice.model.entity.WcsRecordEntity;
import com.xkrs.microservice.model.qo.WcsRecordQo;

import java.time.LocalDate;
import java.util.Optional;

/**
 * 栅格服务管理接口
 * @author tajochen
 */
public interface WcsRecordService {

    /**
     * 获取所有栅格服务
     * @return
     */
    Iterable<WcsRecordEntity> getAllService();

    /**
     * 获取指定服务代码的产品
     * @param serviceCode 服务代码
     * @return
     */
    WcsRecordEntity getByServiceCode(String serviceCode);

    /**
     * 获取指定id的产品
     * @param id 产品编号
     * @return
     */
    Optional<WcsRecordEntity> getById(Integer id);

    /**
     * 获取指定类型的所有服务
     * @param productType 产品类型
     * @return
     */
    Iterable<WcsRecordEntity> getByProductType(String productType);

    /**
     * 获取指定类型和时间段的所有服务
     * @param productType 产品类型
     * @param startDate 开始日期
     * @param endDate 结束日期
     * @return
     */
    Iterable<WcsRecordEntity> getByProductTypeAndDate(String productType, LocalDate startDate,LocalDate endDate);

    /**
     * 获取指定类型和行政区划的所有服务
     * @param admCode 行政区划
     * @param productType 产品类型
     * @return
     */
    Iterable<WcsRecordEntity> getByAdmCodeAndProductType(Integer admCode,String productType);

    /**
     * 获取指定行政区划和时间段的所有服务
     * @param admCode 行政区划代码
     * @param startDate 开始日期
     * @param endDate 行政区划代码
     * @return
     */
    Iterable<WcsRecordEntity> getByAdmCodeAndDate(Integer admCode, LocalDate startDate,LocalDate endDate);

    /**
     * 获取指定类型和行政区划和时间段的所有服务
     * @param admCode 行政区划
     * @param productType 产品类型
     * @param startDate 开始日期
     * @param endDate 结束日期
     * @return
     */
    Iterable<WcsRecordEntity> getByAdmCodeAndProductTypeAndDate(Integer admCode,String productType, LocalDate startDate,LocalDate endDate);

    /**
     * 新增栅格服务
     * @param wcsRecordQo
     * @param userName 用户名
     */
    void add(WcsRecordQo wcsRecordQo, String userName);

    /**
     * 删除栅格服务
     * @param id
     */
    void delete(Integer id);

}
