package com.xkrs.microservice.service.impl;

import com.xkrs.microservice.dao.ShpCityDao;
import com.xkrs.microservice.dao.ShpCountyDao;
import com.xkrs.microservice.model.vo.ShpCityVo;
import com.xkrs.microservice.model.vo.ShpCountyVo;
import com.xkrs.microservice.service.AdministrativeDivisionService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cache.annotation.CacheConfig;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * 行政区划接口
 * @author tajochen
 */
@Service
@CacheConfig(cacheNames = "AdministrativeDivisionServiceCache")
public class AdministrativeDivisionServiceImpl implements AdministrativeDivisionService {

    Logger logger = LoggerFactory.getLogger(AdministrativeDivisionServiceImpl.class);

    @Resource
    private ShpCityDao shpCityDao;

    @Resource
    private ShpCountyDao shpCountyDao;

    /**
     * 获取所有地级市
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public Iterable<ShpCityVo> getAllCity(){
        return shpCityDao.selectAllCity();
    }

    /**
     * 获取所有地级市根据省级代码
     * @param proCode 省级代码
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public Iterable<ShpCityVo> getAllCityByProvinceCode(Integer proCode){
        return shpCityDao.selectAllCityByProvinceCode(proCode);
    }

    /**
     * 获取地级市根据指定地级市编码
     * @param code 地级市代码
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public ShpCityVo getCityByCityCode(Integer code){
        return shpCityDao.selectCityByCityCode(code);
    }

    /**
     * 获取所有区县
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public Iterable<ShpCountyVo> getAllCounty(){
        return shpCountyDao.selectAllCounty();
    }


    /**
     * 获取所有区县根据省级代码
     * @param proCode 省级代码
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public Iterable<ShpCountyVo> getAllCountyByProvinceCode(Integer proCode){
        return shpCountyDao.selectAllCountyByProvinceCode(proCode);
    }

    /**
     * 获取所有区县根据地级市代码
     * @param cityCode 城市代码
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public Iterable<ShpCountyVo> getAllCountyByCityCode(Integer cityCode){
        return shpCountyDao.selectAllCountyByCityCode(cityCode);
    }

    /**
     * 获取指定区县根据区县代码
     * @param countyCode 区县代码
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public ShpCountyVo getCountyByCountyCode(Integer countyCode){
        return shpCountyDao.selectCountyByCountyCode(countyCode);
    }

}
