package com.xkrs.microservice.service.impl;

import com.xkrs.microservice.dao.*;
import com.xkrs.microservice.model.entity.*;
import com.xkrs.microservice.service.DicBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cache.annotation.CacheConfig;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * 文件服务器接口
 * @author tajochen
 */
@Service
@CacheConfig(cacheNames = "DicBusinessServiceServiceCache")
public class DicBusinessServiceServiceImpl implements DicBusinessService {

    Logger logger = LoggerFactory.getLogger(DicBusinessServiceServiceImpl.class);

    @Resource
    private DicSoilClassifyDao dicSoilClassifyDao;

    @Resource
    private DicLandClassifyDao dicLandClassifyDao;

    @Resource
    private DicProductDao dicProductDao;

    @Resource
    private DicDroughtClassifyDao dicDroughtClassifyDao;

    @Resource
    private DicCropClassifyDao dicCropClassifyDao;

    /**
     * 获取所有土壤类型
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public Iterable<DicSoilClassifyEntity> getAllSoilClassify(){
        return dicSoilClassifyDao.findAll();
    }

    /**
     * 获取所有土地利用类型
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public Iterable<DicLandClassifyEntity> getAllLandClassify(){
        return dicLandClassifyDao.findAll();
    }

    /**
     * 获取所有旱情类型
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public Iterable<DicDroughtClassifyEntity> getAllDroughtClassify(){
        return dicDroughtClassifyDao.findAll();
    }

    /**
     * 获取所有种植结构类型
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public Iterable<DicCropClassifyEntity> getAllCropClassify(){
        return dicCropClassifyDao.findAll();
    }

    /**
     * 获取所有产品类型
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public Iterable<DicProductEntity> getAllProduct(){
        return dicProductDao.findAll();
    }

}
