package com.xkrs.microservice.service.impl;

import com.xkrs.microservice.dao.MeteorologicalStationDao;
import com.xkrs.microservice.model.entity.MeteorologicalStationEntity;
import com.xkrs.microservice.model.vo.ForecastWeather7DayVo;
import com.xkrs.microservice.model.vo.RealTimeWeatherVo;
import com.xkrs.microservice.service.MeteorologicalService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cache.annotation.CacheConfig;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

import static com.xkrs.microservice.common.tool.CrawlingWeather7Day.getReptileWeather7Day;
import static com.xkrs.microservice.common.tool.CrawlingWeatherNew.handlerWeatherData;

/**
 * 行政区划接口
 * @author tajochen
 */
@Service
@CacheConfig(cacheNames = "AdministrativeDivisionServiceCache")
public class MeteorologicalServiceImpl implements MeteorologicalService {

    static final Logger logger = LoggerFactory.getLogger(MeteorologicalServiceImpl.class);

    @Resource
    private MeteorologicalStationDao meteorologicalStationDao;

    /**
     * 获取当前行政区划天气
     * @param admCode 行政区划代码
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public RealTimeWeatherVo getWeatherNowByAdmCode(Integer admCode){
        MeteorologicalStationEntity relAdmWeatherStationEntity= meteorologicalStationDao.findByCode(admCode);
        if(relAdmWeatherStationEntity != null){
            RealTimeWeatherVo res = handlerWeatherData(relAdmWeatherStationEntity.getCityWeatherCode().toString());
            return res;
        }
        return null;
    }

    /**
     * 获取行政区划天气预报
     * @param admCode 行政区划代码
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public ForecastWeather7DayVo getWeatherForecastByAdmCode(Integer admCode){
        MeteorologicalStationEntity relAdmWeatherStationEntity= meteorologicalStationDao.findByCode(admCode);
        if(relAdmWeatherStationEntity != null){
            String stationId = "";
            if(relAdmWeatherStationEntity.getStationId()!=null){
                stationId = relAdmWeatherStationEntity.getStationId().toString();
            }
            ForecastWeather7DayVo res = getReptileWeather7Day(relAdmWeatherStationEntity.getCityWeatherCode().toString(),
                    stationId);
            return res;
        }
        return null;
    }

}
