package com.xkrs.microservice.service.impl;

import com.xkrs.microservice.common.tool.PageBean;
import com.xkrs.microservice.dao.WeatherDao;
import com.xkrs.microservice.model.entity.WeatherEntity;
import com.xkrs.microservice.service.WeatherService;
import org.springframework.cache.annotation.CacheConfig;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import java.util.ArrayList;
import java.util.List;

/**
 * @author HP
 */
@Service
@CacheConfig(cacheNames = "WeatherServiceCache")
public class WeatherServiceImpl implements WeatherService {

    @Resource
    private WeatherDao weatherDao;

    /**
     * 动态多条件查询气候信息
     * @param page
     * @param addTimeStart
     * @param addTimeEnd
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public PageBean queryWeather(Integer page, String addTimeStart, String addTimeEnd) {

        Specification<WeatherEntity> specification = new Specification<WeatherEntity>() {
            private static final long serialVersionUID = 1L;

            @Override
            public Predicate toPredicate(Root<WeatherEntity> root, CriteriaQuery<?> query,
                                         CriteriaBuilder criteriaBuilder) {
                List<Predicate> lst = new ArrayList<Predicate>();

                if(addTimeStart != null && !"".equals(addTimeStart)){
                    lst.add(criteriaBuilder.greaterThanOrEqualTo(root.get("addTime").as(String.class), addTimeStart));
                }
                if(addTimeEnd != null && !"".equals(addTimeEnd)){
                    lst.add(criteriaBuilder.lessThanOrEqualTo(root.get("addTime").as(String.class), addTimeEnd));
                }

                return query.where(lst.toArray(new Predicate[] {})).getRestriction();

            }
        };
        System.out.println(specification.toString());

        long count = weatherDao.count(specification);
        PageBean pageBean2 = new PageBean();
        pageBean2.setTotalCount(count);
        pageBean2.setPageSize(10);
        // addTime表示按数据库中哪个字段排序，DESC倒序
        Pageable pageable = PageRequest.of(page - 1,pageBean2.getPageSize(), Sort.by(Sort.Direction.DESC, "addTime"));
        // 封装分页查询条件
        Page<WeatherEntity> emailGradeTaskList = weatherDao.findAll(specification, pageable);
        pageBean2.setList(emailGradeTaskList.getContent());
        return pageBean2;
    }

    /**
     * 根据时间查询气象信息
     * @param startTime
     * @param endTime
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator", unless="#result == null")
    @Override
    public List<WeatherEntity> selectWeather(String startTime, String endTime) {
        Specification<WeatherEntity> specification = new Specification<WeatherEntity>() {
            @Override
            public Predicate toPredicate(Root<WeatherEntity> root, CriteriaQuery<?> criteriaQuery, CriteriaBuilder criteriaBuilder) {
                List<Predicate> list = new ArrayList<>();
                if(startTime != null && !"".equals(startTime)){
                    list.add(criteriaBuilder.greaterThanOrEqualTo(root.get("addTime").as(String.class), startTime));
                }
                if(endTime != null && !"".equals(endTime)){
                    list.add(criteriaBuilder.lessThanOrEqualTo(root.get("addTime").as(String.class), endTime));
                }
                Predicate[] predicates = new Predicate[list.size()];
                return criteriaBuilder.and(list.toArray(predicates));
            }
        };
        return weatherDao.findAll(specification);
    }
}
