package com.xkrs.microservice.util;

/**
 * 数字工具
 * @author tajochen
 */
public class NumberUtil {

    private final static int MIN_CODE = 110000;
    private final static int MAX_CODE = 999999;

    /**
     * 检查字符串是否为数字
     * @param str 字符串
     * @return
     */
    public static boolean isStrNumeric(String str) {
        if(str==null||str.length()==0){
            return false;
        }
        for (int i = 0; i < str.length(); i++) {
            System.out.println(str.charAt(i));
            if (!Character.isDigit(str.charAt(i))) {
                return false;
            }
        }
        return true;
    }

    /**
     * 检查字符串是否为行政区划代码,共六位
     * @param str 字符串
     * @return
     */
    public static boolean isStrAdmCode(String str) {
        if(isStrNumeric(str)){
            try {
                int theNum = Integer.parseInt(str);
                if(MIN_CODE < theNum && theNum < MAX_CODE){
                    return true;
                }
            } catch (NumberFormatException e){
                return false;
            }
        }
        return false;
    }

    /**
     * 欧拉筛法：保证每个合数只会被它的最小质因数筛掉，时间复杂度降低到O(n)。
     * 每一个数都去乘以当前素数表里面已有的数，当 indexI 是合数，
     * 且 indexI % primeList[indexJ] == 0 时，只能乘以第一个素数 2
     * @param num 最大数字
     * @return
     */
    public static int[] eulerScreening(int num) {
        boolean[] check = new boolean[num+1];
        int[] primeList = new int[num+1];
        int count = 0;
        for (int indexI = 2; indexI <= num; indexI++) {
            if (!check[indexI]) {
                primeList[count++] = indexI;
            }
            // 每一个数都去乘以当前素数表里面已有的数，如果 indexI 是合数，且 indexI % primeList[indexJ] == 0，那么它只能乘以第一个素数 2
            // 如：2×2、3×(2、3)、4×(2)、5×(2、3、5)、6×(2)、7×(2、3、5、7)、8×(2)、9×(2、3)、10×(2)
            for (int indexJ = 0; indexJ < count; indexJ++) {
                // 过大的时候跳出
                if (indexI * primeList[indexJ] > num) {
                    break;
                }
                check[indexI * primeList[indexJ]] = true;
                // 如果 indexI 是一个合数，而且 indexI % primeList[indexJ] == 0
                // 保证了每个合数只会被它的最小素因子筛掉
                if (indexI % primeList[indexJ] == 0) {
                    break;
                }
            }
        }
        return primeList;
    }

    public static void main(String[] args) {
        long start = System.currentTimeMillis();
        int[] primeList = eulerScreening(149);
        long end = System.currentTimeMillis();
        System.out.println("耗时共 "+ (end - start)+" 毫秒");
    }

}
